# SPDX-FileCopyrightText: 2024 Jarmo Tiitto <jarmo.tiitto@gmail.com>
# SPDX-License-Identifier: GPL-2.0-or-later
import socket
import threading
import struct
import os
import sys
from enum import IntEnum

# This module provides a few things:
# - kdevPdbConnection.establish() Wait for a client to connect up and initialize
# - kdevPdbConnection.sendDataFrame() Write a data frame to a peer.
# - kdevPdbConnection.getDataFrame()  Get/Wait for a data frame from a peer.
# - The received data frames are appended to a queue by the I/O thread that runs the
#   socket recv() system calls. The receive threading guarantees forward progress in
#   the case both peers send data simultaneously.
# - Sending a data frame blocks the caller until the full frame is sent.


class Stop(BaseException):
    pass


# Currently defined data-frame protocol escape codes.
class Cmd(IntEnum):
    DoNothing = 0
    Terminate = -1
    InterruptDisallowed = -2
    InterruptAllowed = -3


class kdevPdbConnection:

    def __init__(self):
        # queue of received bytes() data-frames.
        self.dataframes = []
        self.condvar = threading.Condition(threading.Lock())
        # Has recv() side of the socket been closed?
        self.stop_read = False
        # Has send() side of the socket been closed? (not guarded by condvar)
        self.stop_write = False
        self.recv_thread = None
        self.server_address = None
        self.socket = None

    def establish(self, socketpath="/tmp/"):
        """Become a server listening for a client"""
        # Initialize the IO.
        socket_addr = socketpath + "kdevpdb.socket"
        if os.path.exists(socket_addr):
            os.unlink(socket_addr)
        listensocket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
        if hasattr(socket, "SO_REUSEADDR"):
            listensocket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        listensocket.bind(socket_addr)
        self.server_address = listensocket.getsockname()
        listensocket.listen(0)
        # Print the socket file to stdout.
        # The host process must wait for "socket:" line to be printed, and discard this line.
        sys.stdout.write("socket:"+self.server_address+"\n")
        sys.stdout.flush()
        self.socket, _ = listensocket.accept()
        listensocket.close()
        self.recv_thread = threading.Thread(target=self._recv)
        self.recv_thread.start()

    def _shutdown(self, shutread, shutwrite):
        '''Shutdown the connection.
           The shutdown is done such that we send CmdTerminate first if we are fully open.
           This gives the remote peer a chance to also cleanly shutdown the connection.
        '''
        if shutwrite and not self.stop_write:
            with self.condvar:
                if not self.stop_read:
                    # the connection is fully open. Try make the remote peer shutdown cleanly.
                    self.sendCmdFrame(Cmd.Terminate)
                self.stop_write = True
                if shutread:
                    # Full shutdown, the reader side is already or will be dead.
                    self.stop_read = True
                    self.socket.shutdown(socket.SHUT_RDWR)
                    self.condvar.notify()
                    # the socket is *dead*.
                    self.socket.close()
                    self.socket = None
                    return
                # Shutdown only writer side.
                self.socket.shutdown(socket.SHUT_WR)
        elif shutread:
            # Shutdown the reader side only.
            with self.condvar:
                if not self.stop_read:
                    self.stop_read = True
                    self.socket.shutdown(socket.SHUT_RD)
                    self.condvar.notify()
                    if self.stop_write:
                        self.socket.close()
                        self.socket = None

    def _recv(self):
        '''A receiver thread that shovels data frames from the socket into the queue'''
        try:
            while True:
                blob = self._recvDataFrame()
                with self.condvar:
                    self.dataframes.append(blob)
                    self.condvar.notify()
        except Stop:
            pass
        except BaseException as e:
            print(e)
        # Close the receiving side of the socket.
        self._shutdown(True, False)

    def getDataFrame(self):
        with self.condvar:
            while not self.dataframes:
                if self.stop_read:
                    raise Stop()
                self.condvar.wait()
            return self.dataframes.pop(0)

    def stop(self):
        '''request shutdown of receiver thread and connection'''
        if self.socket is not None:
            self._shutdown(True, True)
        if self.recv_thread is not None:
            self.recv_thread.join()

    def sendCmdFrame(self, code):
        '''Send a escape code only frame'''
        assert not self.stop_write
        sendbuf = struct.pack('<i', code)
        try:
            self.socket.sendall(sendbuf)
        finally:
            pass

    def sendDataFrame(self, src):
        '''Send a frame of data'''
        sendbuf = bytearray(struct.pack('<i', len(src)) + src)
        nbytes = 0
        if self.stop_write:
            raise Stop()
        while nbytes < len(sendbuf):
            # TODO: handle any errors that we should recover from and try sending again.
            numbytes = self.socket.send(sendbuf[nbytes:])
            if numbytes > 0:
                nbytes += numbytes
            else:
                # failed to send anything, close the sending side and abort.
                self._shutdown(False, True)
                raise Stop()

    def _recvDataFrame(self):
        '''Receive a frame of data or None'''
        recv = struct.calcsize('<i')  # max length of data to receive
        # the receive buffer. Most of the frames can fit into the 4096 bytes.
        recvbuf = bytearray(4096)
        datablob = bytearray()
        bloblen = -1
        while recv > 0:
            numbytes = self.socket.recv_into(recvbuf, recv)
            if bloblen == -1 and numbytes == recv:
                # 1. got the blob length (which can be less than one for special events)
                bloblen = struct.unpack_from('<i', recvbuf, 0)[0]
                if bloblen == Cmd.DoNothing:
                    # A empty blob.
                    return None
                if bloblen == Cmd.Terminate:
                    # End the connection now.
                    raise Stop()
                if bloblen > len(recvbuf):
                    # reserve a big enough buffer..
                    recvbuf = bytearray(bloblen)
                # Ok, start receiving the payload.
                recv = bloblen
            elif bloblen > 0 and numbytes > 0:
                # 2. got some data
                datablob += recvbuf[:numbytes]
                recv -= numbytes
            else:
                # Error.
                raise Stop()
        # successfully received a data frame
        return datablob



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QGraphicsWebView(QGraphicsWidget):
    """"""
    def __init__(self, parent = None):
        '''void QGraphicsWebView.__init__(QGraphicsItem parent = None)'''
    def setRenderHint(self, hint, enabled = True):
        '''void QGraphicsWebView.setRenderHint(QPainter.RenderHint hint, bool enabled = True)'''
    def setRenderHints(self, hints):
        '''void QGraphicsWebView.setRenderHints(QPainter.RenderHints hints)'''
    def renderHints(self):
        '''QPainter.RenderHints QGraphicsWebView.renderHints()'''
        return QPainter.RenderHints()
    def setTiledBackingStoreFrozen(self, frozen):
        '''void QGraphicsWebView.setTiledBackingStoreFrozen(bool frozen)'''
    def isTiledBackingStoreFrozen(self):
        '''bool QGraphicsWebView.isTiledBackingStoreFrozen()'''
        return bool()
    def setResizesToContents(self, enabled):
        '''void QGraphicsWebView.setResizesToContents(bool enabled)'''
    def resizesToContents(self):
        '''bool QGraphicsWebView.resizesToContents()'''
        return bool()
    def sceneEvent(self):
        '''QEvent QGraphicsWebView.sceneEvent()'''
        return QEvent()
    def focusNextPrevChild(self, next):
        '''bool QGraphicsWebView.focusNextPrevChild(bool next)'''
        return bool()
    def inputMethodEvent(self):
        '''QInputMethodEvent QGraphicsWebView.inputMethodEvent()'''
        return QInputMethodEvent()
    def focusOutEvent(self):
        '''QFocusEvent QGraphicsWebView.focusOutEvent()'''
        return QFocusEvent()
    def focusInEvent(self):
        '''QFocusEvent QGraphicsWebView.focusInEvent()'''
        return QFocusEvent()
    def dropEvent(self):
        '''QGraphicsSceneDragDropEvent QGraphicsWebView.dropEvent()'''
        return QGraphicsSceneDragDropEvent()
    def dragMoveEvent(self):
        '''QGraphicsSceneDragDropEvent QGraphicsWebView.dragMoveEvent()'''
        return QGraphicsSceneDragDropEvent()
    def dragLeaveEvent(self):
        '''QGraphicsSceneDragDropEvent QGraphicsWebView.dragLeaveEvent()'''
        return QGraphicsSceneDragDropEvent()
    def dragEnterEvent(self):
        '''QGraphicsSceneDragDropEvent QGraphicsWebView.dragEnterEvent()'''
        return QGraphicsSceneDragDropEvent()
    def contextMenuEvent(self):
        '''QGraphicsSceneContextMenuEvent QGraphicsWebView.contextMenuEvent()'''
        return QGraphicsSceneContextMenuEvent()
    def keyReleaseEvent(self):
        '''QKeyEvent QGraphicsWebView.keyReleaseEvent()'''
        return QKeyEvent()
    def keyPressEvent(self):
        '''QKeyEvent QGraphicsWebView.keyPressEvent()'''
        return QKeyEvent()
    def wheelEvent(self):
        '''QGraphicsSceneWheelEvent QGraphicsWebView.wheelEvent()'''
        return QGraphicsSceneWheelEvent()
    def hoverLeaveEvent(self):
        '''QGraphicsSceneHoverEvent QGraphicsWebView.hoverLeaveEvent()'''
        return QGraphicsSceneHoverEvent()
    def hoverMoveEvent(self):
        '''QGraphicsSceneHoverEvent QGraphicsWebView.hoverMoveEvent()'''
        return QGraphicsSceneHoverEvent()
    def mouseMoveEvent(self):
        '''QGraphicsSceneMouseEvent QGraphicsWebView.mouseMoveEvent()'''
        return QGraphicsSceneMouseEvent()
    def mouseReleaseEvent(self):
        '''QGraphicsSceneMouseEvent QGraphicsWebView.mouseReleaseEvent()'''
        return QGraphicsSceneMouseEvent()
    def mouseDoubleClickEvent(self):
        '''QGraphicsSceneMouseEvent QGraphicsWebView.mouseDoubleClickEvent()'''
        return QGraphicsSceneMouseEvent()
    def mousePressEvent(self):
        '''QGraphicsSceneMouseEvent QGraphicsWebView.mousePressEvent()'''
        return QGraphicsSceneMouseEvent()
    linkClicked = pyqtSignal() # void linkClicked(const QUrlamp;) - signal
    statusBarMessage = pyqtSignal() # void statusBarMessage(const QStringamp;) - signal
    iconChanged = pyqtSignal() # void iconChanged() - signal
    titleChanged = pyqtSignal() # void titleChanged(const QStringamp;) - signal
    urlChanged = pyqtSignal() # void urlChanged(const QUrlamp;) - signal
    loadProgress = pyqtSignal() # void loadProgress(int) - signal
    loadFinished = pyqtSignal() # void loadFinished(bool) - signal
    loadStarted = pyqtSignal() # void loadStarted() - signal
    def reload(self):
        '''void QGraphicsWebView.reload()'''
    def forward(self):
        '''void QGraphicsWebView.forward()'''
    def back(self):
        '''void QGraphicsWebView.back()'''
    def stop(self):
        '''void QGraphicsWebView.stop()'''
    def inputMethodQuery(self, query):
        '''QVariant QGraphicsWebView.inputMethodQuery(Qt.InputMethodQuery query)'''
        return QVariant()
    def sizeHint(self, which, constraint):
        '''QSizeF QGraphicsWebView.sizeHint(Qt.SizeHint which, QSizeF constraint)'''
        return QSizeF()
    def event(self):
        '''QEvent QGraphicsWebView.event()'''
        return QEvent()
    def itemChange(self, change, value):
        '''QVariant QGraphicsWebView.itemChange(QGraphicsItem.GraphicsItemChange change, QVariant value)'''
        return QVariant()
    def paint(self, painter, option, widget = None):
        '''void QGraphicsWebView.paint(QPainter painter, QStyleOptionGraphicsItem option, QWidget widget = None)'''
    def updateGeometry(self):
        '''void QGraphicsWebView.updateGeometry()'''
    def setGeometry(self, rect):
        '''void QGraphicsWebView.setGeometry(QRectF rect)'''
    def findText(self, subString, options = 0):
        '''bool QGraphicsWebView.findText(QString subString, QWebPage.FindFlags options = 0)'''
        return bool()
    def triggerPageAction(self, action, checked = False):
        '''void QGraphicsWebView.triggerPageAction(QWebPage.WebAction action, bool checked = False)'''
    def pageAction(self, action):
        '''QAction QGraphicsWebView.pageAction(QWebPage.WebAction action)'''
        return QAction()
    def settings(self):
        '''QWebSettings QGraphicsWebView.settings()'''
        return QWebSettings()
    def history(self):
        '''QWebHistory QGraphicsWebView.history()'''
        return QWebHistory()
    def setContent(self, data, mimeType = QString(), baseUrl = QUrl()):
        '''void QGraphicsWebView.setContent(QByteArray data, QString mimeType = QString(), QUrl baseUrl = QUrl())'''
    def setHtml(self, html, baseUrl = QUrl()):
        '''void QGraphicsWebView.setHtml(QString html, QUrl baseUrl = QUrl())'''
    def load(self, url):
        '''void QGraphicsWebView.load(QUrl url)'''
    def load(self, request, operation = None, body = QByteArray()):
        '''void QGraphicsWebView.load(QNetworkRequest request, QNetworkAccessManager.Operation operation = QNetworkAccessManager.GetOperation, QByteArray body = QByteArray())'''
    def isModified(self):
        '''bool QGraphicsWebView.isModified()'''
        return bool()
    def setZoomFactor(self):
        '''float QGraphicsWebView.setZoomFactor()'''
        return float()
    def zoomFactor(self):
        '''float QGraphicsWebView.zoomFactor()'''
        return float()
    def icon(self):
        '''QIcon QGraphicsWebView.icon()'''
        return QIcon()
    def title(self):
        '''QString QGraphicsWebView.title()'''
        return QString()
    def setUrl(self):
        '''QUrl QGraphicsWebView.setUrl()'''
        return QUrl()
    def url(self):
        '''QUrl QGraphicsWebView.url()'''
        return QUrl()
    def setPage(self):
        '''QWebPage QGraphicsWebView.setPage()'''
        return QWebPage()
    def page(self):
        '''QWebPage QGraphicsWebView.page()'''
        return QWebPage()


class QWebDatabase():
    """"""
    def __init__(self, other):
        '''void QWebDatabase.__init__(QWebDatabase other)'''
    def removeAllDatabases(self):
        '''static void QWebDatabase.removeAllDatabases()'''
    def removeDatabase(self, db):
        '''static void QWebDatabase.removeDatabase(QWebDatabase db)'''
    def origin(self):
        '''QWebSecurityOrigin QWebDatabase.origin()'''
        return QWebSecurityOrigin()
    def fileName(self):
        '''QString QWebDatabase.fileName()'''
        return QString()
    def size(self):
        '''int QWebDatabase.size()'''
        return int()
    def expectedSize(self):
        '''int QWebDatabase.expectedSize()'''
        return int()
    def displayName(self):
        '''QString QWebDatabase.displayName()'''
        return QString()
    def name(self):
        '''QString QWebDatabase.name()'''
        return QString()


class QWebElement():
    """"""
    # Enum QWebElement.StyleResolveStrategy
    InlineStyle = 0
    CascadedStyle = 0
    ComputedStyle = 0

    def __init__(self):
        '''void QWebElement.__init__()'''
    def __init__(self):
        '''QWebElement QWebElement.__init__()'''
        return QWebElement()
    def render(self, painter):
        '''void QWebElement.render(QPainter painter)'''
    def render(self, painter, clip):
        '''void QWebElement.render(QPainter painter, QRect clip)'''
    def setStyleProperty(self, name, value):
        '''void QWebElement.setStyleProperty(QString name, QString value)'''
    def styleProperty(self, name, strategy):
        '''QString QWebElement.styleProperty(QString name, QWebElement.StyleResolveStrategy strategy)'''
        return QString()
    def evaluateJavaScript(self, scriptSource):
        '''QVariant QWebElement.evaluateJavaScript(QString scriptSource)'''
        return QVariant()
    def removeAllChildren(self):
        '''void QWebElement.removeAllChildren()'''
    def removeFromDocument(self):
        '''void QWebElement.removeFromDocument()'''
    def takeFromDocument(self):
        '''QWebElement QWebElement.takeFromDocument()'''
        return QWebElement()
    def clone(self):
        '''QWebElement QWebElement.clone()'''
        return QWebElement()
    def replace(self, markup):
        '''void QWebElement.replace(QString markup)'''
    def replace(self, element):
        '''void QWebElement.replace(QWebElement element)'''
    def encloseWith(self, markup):
        '''void QWebElement.encloseWith(QString markup)'''
    def encloseWith(self, element):
        '''void QWebElement.encloseWith(QWebElement element)'''
    def encloseContentsWith(self, element):
        '''void QWebElement.encloseContentsWith(QWebElement element)'''
    def encloseContentsWith(self, markup):
        '''void QWebElement.encloseContentsWith(QString markup)'''
    def prependOutside(self, markup):
        '''void QWebElement.prependOutside(QString markup)'''
    def prependOutside(self, element):
        '''void QWebElement.prependOutside(QWebElement element)'''
    def appendOutside(self, markup):
        '''void QWebElement.appendOutside(QString markup)'''
    def appendOutside(self, element):
        '''void QWebElement.appendOutside(QWebElement element)'''
    def prependInside(self, markup):
        '''void QWebElement.prependInside(QString markup)'''
    def prependInside(self, element):
        '''void QWebElement.prependInside(QWebElement element)'''
    def appendInside(self, markup):
        '''void QWebElement.appendInside(QString markup)'''
    def appendInside(self, element):
        '''void QWebElement.appendInside(QWebElement element)'''
    def webFrame(self):
        '''QWebFrame QWebElement.webFrame()'''
        return QWebFrame()
    def document(self):
        '''QWebElement QWebElement.document()'''
        return QWebElement()
    def previousSibling(self):
        '''QWebElement QWebElement.previousSibling()'''
        return QWebElement()
    def nextSibling(self):
        '''QWebElement QWebElement.nextSibling()'''
        return QWebElement()
    def lastChild(self):
        '''QWebElement QWebElement.lastChild()'''
        return QWebElement()
    def firstChild(self):
        '''QWebElement QWebElement.firstChild()'''
        return QWebElement()
    def parent(self):
        '''QWebElement QWebElement.parent()'''
        return QWebElement()
    def namespaceUri(self):
        '''QString QWebElement.namespaceUri()'''
        return QString()
    def localName(self):
        '''QString QWebElement.localName()'''
        return QString()
    def prefix(self):
        '''QString QWebElement.prefix()'''
        return QString()
    def tagName(self):
        '''QString QWebElement.tagName()'''
        return QString()
    def geometry(self):
        '''QRect QWebElement.geometry()'''
        return QRect()
    def setFocus(self):
        '''void QWebElement.setFocus()'''
    def hasFocus(self):
        '''bool QWebElement.hasFocus()'''
        return bool()
    def toggleClass(self, name):
        '''void QWebElement.toggleClass(QString name)'''
    def removeClass(self, name):
        '''void QWebElement.removeClass(QString name)'''
    def addClass(self, name):
        '''void QWebElement.addClass(QString name)'''
    def hasClass(self, name):
        '''bool QWebElement.hasClass(QString name)'''
        return bool()
    def classes(self):
        '''QStringList QWebElement.classes()'''
        return QStringList()
    def attributeNames(self, namespaceUri = QString()):
        '''QStringList QWebElement.attributeNames(QString namespaceUri = QString())'''
        return QStringList()
    def hasAttributes(self):
        '''bool QWebElement.hasAttributes()'''
        return bool()
    def removeAttributeNS(self, namespaceUri, name):
        '''void QWebElement.removeAttributeNS(QString namespaceUri, QString name)'''
    def removeAttribute(self, name):
        '''void QWebElement.removeAttribute(QString name)'''
    def hasAttributeNS(self, namespaceUri, name):
        '''bool QWebElement.hasAttributeNS(QString namespaceUri, QString name)'''
        return bool()
    def hasAttribute(self, name):
        '''bool QWebElement.hasAttribute(QString name)'''
        return bool()
    def attributeNS(self, namespaceUri, name, defaultValue = QString()):
        '''QString QWebElement.attributeNS(QString namespaceUri, QString name, QString defaultValue = QString())'''
        return QString()
    def attribute(self, name, defaultValue = QString()):
        '''QString QWebElement.attribute(QString name, QString defaultValue = QString())'''
        return QString()
    def setAttributeNS(self, namespaceUri, name, value):
        '''void QWebElement.setAttributeNS(QString namespaceUri, QString name, QString value)'''
    def setAttribute(self, name, value):
        '''void QWebElement.setAttribute(QString name, QString value)'''
    def toInnerXml(self):
        '''QString QWebElement.toInnerXml()'''
        return QString()
    def setInnerXml(self, markup):
        '''void QWebElement.setInnerXml(QString markup)'''
    def toOuterXml(self):
        '''QString QWebElement.toOuterXml()'''
        return QString()
    def setOuterXml(self, markup):
        '''void QWebElement.setOuterXml(QString markup)'''
    def toPlainText(self):
        '''QString QWebElement.toPlainText()'''
        return QString()
    def setPlainText(self, text):
        '''void QWebElement.setPlainText(QString text)'''
    def findFirst(self, selectorQuery):
        '''QWebElement QWebElement.findFirst(QString selectorQuery)'''
        return QWebElement()
    def findAll(self, selectorQuery):
        '''QWebElementCollection QWebElement.findAll(QString selectorQuery)'''
        return QWebElementCollection()
    def isNull(self):
        '''bool QWebElement.isNull()'''
        return bool()
    def __ne__(self, o):
        '''bool QWebElement.__ne__(QWebElement o)'''
        return bool()
    def __eq__(self, o):
        '''bool QWebElement.__eq__(QWebElement o)'''
        return bool()


class QWebElementCollection():
    """"""
    def __init__(self):
        '''void QWebElementCollection.__init__()'''
    def __init__(self, contextElement, query):
        '''void QWebElementCollection.__init__(QWebElement contextElement, QString query)'''
    def __init__(self):
        '''QWebElementCollection QWebElementCollection.__init__()'''
        return QWebElementCollection()
    def toList(self):
        '''list-of-QWebElement QWebElementCollection.toList()'''
        return [QWebElement()]
    def last(self):
        '''QWebElement QWebElementCollection.last()'''
        return QWebElement()
    def first(self):
        '''QWebElement QWebElementCollection.first()'''
        return QWebElement()
    def __getitem__(self, i):
        '''QWebElement QWebElementCollection.__getitem__(int i)'''
        return QWebElement()
    def at(self, i):
        '''QWebElement QWebElementCollection.at(int i)'''
        return QWebElement()
    def __len__(self):
        '''None QWebElementCollection.__len__()'''
        return None()
    def count(self):
        '''int QWebElementCollection.count()'''
        return int()
    def append(self, collection):
        '''void QWebElementCollection.append(QWebElementCollection collection)'''
    def __iadd__(self, other):
        '''QWebElementCollection QWebElementCollection.__iadd__(QWebElementCollection other)'''
        return QWebElementCollection()
    def __add__(self, other):
        '''QWebElementCollection QWebElementCollection.__add__(QWebElementCollection other)'''
        return QWebElementCollection()


class QWebHitTestResult():
    """"""
    def __init__(self):
        '''void QWebHitTestResult.__init__()'''
    def __init__(self, other):
        '''void QWebHitTestResult.__init__(QWebHitTestResult other)'''
    def element(self):
        '''QWebElement QWebHitTestResult.element()'''
        return QWebElement()
    def linkElement(self):
        '''QWebElement QWebHitTestResult.linkElement()'''
        return QWebElement()
    def enclosingBlockElement(self):
        '''QWebElement QWebHitTestResult.enclosingBlockElement()'''
        return QWebElement()
    def boundingRect(self):
        '''QRect QWebHitTestResult.boundingRect()'''
        return QRect()
    def frame(self):
        '''QWebFrame QWebHitTestResult.frame()'''
        return QWebFrame()
    def isContentSelected(self):
        '''bool QWebHitTestResult.isContentSelected()'''
        return bool()
    def isContentEditable(self):
        '''bool QWebHitTestResult.isContentEditable()'''
        return bool()
    def pixmap(self):
        '''QPixmap QWebHitTestResult.pixmap()'''
        return QPixmap()
    def imageUrl(self):
        '''QUrl QWebHitTestResult.imageUrl()'''
        return QUrl()
    def alternateText(self):
        '''QString QWebHitTestResult.alternateText()'''
        return QString()
    def linkTargetFrame(self):
        '''QWebFrame QWebHitTestResult.linkTargetFrame()'''
        return QWebFrame()
    def linkTitle(self):
        '''QUrl QWebHitTestResult.linkTitle()'''
        return QUrl()
    def linkUrl(self):
        '''QUrl QWebHitTestResult.linkUrl()'''
        return QUrl()
    def linkText(self):
        '''QString QWebHitTestResult.linkText()'''
        return QString()
    def title(self):
        '''QString QWebHitTestResult.title()'''
        return QString()
    def pos(self):
        '''QPoint QWebHitTestResult.pos()'''
        return QPoint()
    def isNull(self):
        '''bool QWebHitTestResult.isNull()'''
        return bool()


class QWebFrame(QObject):
    """"""
    # Enum QWebFrame.RenderLayer
    ContentsLayer = 0
    ScrollBarLayer = 0
    PanIconLayer = 0
    AllLayers = 0

    pageChanged = pyqtSignal() # void pageChanged() - signal
    def scrollToAnchor(self, anchor):
        '''void QWebFrame.scrollToAnchor(QString anchor)'''
    loadFinished = pyqtSignal() # void loadFinished(bool) - signal
    loadStarted = pyqtSignal() # void loadStarted() - signal
    contentsSizeChanged = pyqtSignal() # void contentsSizeChanged(const QSizeamp;) - signal
    def findFirstElement(self, selectorQuery):
        '''QWebElement QWebFrame.findFirstElement(QString selectorQuery)'''
        return QWebElement()
    def findAllElements(self, selectorQuery):
        '''QWebElementCollection QWebFrame.findAllElements(QString selectorQuery)'''
        return QWebElementCollection()
    def documentElement(self):
        '''QWebElement QWebFrame.documentElement()'''
        return QWebElement()
    def setFocus(self):
        '''void QWebFrame.setFocus()'''
    def hasFocus(self):
        '''bool QWebFrame.hasFocus()'''
        return bool()
    def scrollBarGeometry(self, orientation):
        '''QRect QWebFrame.scrollBarGeometry(Qt.Orientation orientation)'''
        return QRect()
    def baseUrl(self):
        '''QUrl QWebFrame.baseUrl()'''
        return QUrl()
    def requestedUrl(self):
        '''QUrl QWebFrame.requestedUrl()'''
        return QUrl()
    def securityOrigin(self):
        '''QWebSecurityOrigin QWebFrame.securityOrigin()'''
        return QWebSecurityOrigin()
    def setZoomFactor(self, factor):
        '''void QWebFrame.setZoomFactor(float factor)'''
    def zoomFactor(self):
        '''float QWebFrame.zoomFactor()'''
        return float()
    def setScrollPosition(self, pos):
        '''void QWebFrame.setScrollPosition(QPoint pos)'''
    def scrollPosition(self):
        '''QPoint QWebFrame.scrollPosition()'''
        return QPoint()
    def scroll(self):
        '''int QWebFrame.scroll()'''
        return int()
    def metaData(self):
        '''dict-of-QString-list-of-QString QWebFrame.metaData()'''
        return dict-of-QString-list-of-QString()
    iconChanged = pyqtSignal() # void iconChanged() - signal
    initialLayoutCompleted = pyqtSignal() # void initialLayoutCompleted() - signal
    urlChanged = pyqtSignal() # void urlChanged(const QUrlamp;) - signal
    titleChanged = pyqtSignal() # void titleChanged(const QStringamp;) - signal
    javaScriptWindowObjectCleared = pyqtSignal() # void javaScriptWindowObjectCleared() - signal
    def print_(self, printer):
        '''void QWebFrame.print_(QPrinter printer)'''
    def evaluateJavaScript(self, scriptSource):
        '''QVariant QWebFrame.evaluateJavaScript(QString scriptSource)'''
        return QVariant()
    def event(self):
        '''QEvent QWebFrame.event()'''
        return QEvent()
    def hitTestContent(self, pos):
        '''QWebHitTestResult QWebFrame.hitTestContent(QPoint pos)'''
        return QWebHitTestResult()
    def contentsSize(self):
        '''QSize QWebFrame.contentsSize()'''
        return QSize()
    def geometry(self):
        '''QRect QWebFrame.geometry()'''
        return QRect()
    def pos(self):
        '''QPoint QWebFrame.pos()'''
        return QPoint()
    def textSizeMultiplier(self):
        '''float QWebFrame.textSizeMultiplier()'''
        return float()
    def setTextSizeMultiplier(self, factor):
        '''void QWebFrame.setTextSizeMultiplier(float factor)'''
    def render(self, painter, clip):
        '''void QWebFrame.render(QPainter painter, QRegion clip)'''
    def render(self, painter):
        '''void QWebFrame.render(QPainter painter)'''
    def render(self, layer, clip = QRegion()):
        '''QPainter QWebFrame.render(QWebFrame.RenderLayer layer, QRegion clip = QRegion())'''
        return QPainter()
    def scrollBarMaximum(self, orientation):
        '''int QWebFrame.scrollBarMaximum(Qt.Orientation orientation)'''
        return int()
    def scrollBarMinimum(self, orientation):
        '''int QWebFrame.scrollBarMinimum(Qt.Orientation orientation)'''
        return int()
    def scrollBarValue(self, orientation):
        '''int QWebFrame.scrollBarValue(Qt.Orientation orientation)'''
        return int()
    def setScrollBarValue(self, orientation, value):
        '''void QWebFrame.setScrollBarValue(Qt.Orientation orientation, int value)'''
    def setScrollBarPolicy(self, orientation, policy):
        '''void QWebFrame.setScrollBarPolicy(Qt.Orientation orientation, Qt.ScrollBarPolicy policy)'''
    def scrollBarPolicy(self, orientation):
        '''Qt.ScrollBarPolicy QWebFrame.scrollBarPolicy(Qt.Orientation orientation)'''
        return Qt.ScrollBarPolicy()
    def childFrames(self):
        '''list-of-QWebFrame QWebFrame.childFrames()'''
        return [QWebFrame()]
    def parentFrame(self):
        '''QWebFrame QWebFrame.parentFrame()'''
        return QWebFrame()
    def frameName(self):
        '''QString QWebFrame.frameName()'''
        return QString()
    def icon(self):
        '''QIcon QWebFrame.icon()'''
        return QIcon()
    def url(self):
        '''QUrl QWebFrame.url()'''
        return QUrl()
    def setUrl(self, url):
        '''void QWebFrame.setUrl(QUrl url)'''
    def title(self):
        '''QString QWebFrame.title()'''
        return QString()
    def renderTreeDump(self):
        '''QString QWebFrame.renderTreeDump()'''
        return QString()
    def toPlainText(self):
        '''QString QWebFrame.toPlainText()'''
        return QString()
    def toHtml(self):
        '''QString QWebFrame.toHtml()'''
        return QString()
    def addToJavaScriptWindowObject(self, name, object):
        '''void QWebFrame.addToJavaScriptWindowObject(QString name, QObject object)'''
    def setContent(self, data, mimeType = QString(), baseUrl = QUrl()):
        '''void QWebFrame.setContent(QByteArray data, QString mimeType = QString(), QUrl baseUrl = QUrl())'''
    def setHtml(self, html, baseUrl = QUrl()):
        '''void QWebFrame.setHtml(QString html, QUrl baseUrl = QUrl())'''
    def load(self, url):
        '''void QWebFrame.load(QUrl url)'''
    def load(self, request, operation = None, body = QByteArray()):
        '''void QWebFrame.load(QNetworkRequest request, QNetworkAccessManager.Operation operation = QNetworkAccessManager.GetOperation, QByteArray body = QByteArray())'''
    def page(self):
        '''QWebPage QWebFrame.page()'''
        return QWebPage()


class QWebHistoryItem():
    """"""
    def __init__(self, other):
        '''void QWebHistoryItem.__init__(QWebHistoryItem other)'''
    def isValid(self):
        '''bool QWebHistoryItem.isValid()'''
        return bool()
    def setUserData(self, userData):
        '''void QWebHistoryItem.setUserData(QVariant userData)'''
    def userData(self):
        '''QVariant QWebHistoryItem.userData()'''
        return QVariant()
    def icon(self):
        '''QIcon QWebHistoryItem.icon()'''
        return QIcon()
    def lastVisited(self):
        '''QDateTime QWebHistoryItem.lastVisited()'''
        return QDateTime()
    def title(self):
        '''QString QWebHistoryItem.title()'''
        return QString()
    def url(self):
        '''QUrl QWebHistoryItem.url()'''
        return QUrl()
    def originalUrl(self):
        '''QUrl QWebHistoryItem.originalUrl()'''
        return QUrl()


class QWebHistory():
    """"""
    def setMaximumItemCount(self, count):
        '''void QWebHistory.setMaximumItemCount(int count)'''
    def maximumItemCount(self):
        '''int QWebHistory.maximumItemCount()'''
        return int()
    def currentItemIndex(self):
        '''int QWebHistory.currentItemIndex()'''
        return int()
    def __len__(self):
        '''None QWebHistory.__len__()'''
        return None()
    def count(self):
        '''int QWebHistory.count()'''
        return int()
    def itemAt(self, i):
        '''QWebHistoryItem QWebHistory.itemAt(int i)'''
        return QWebHistoryItem()
    def forwardItem(self):
        '''QWebHistoryItem QWebHistory.forwardItem()'''
        return QWebHistoryItem()
    def currentItem(self):
        '''QWebHistoryItem QWebHistory.currentItem()'''
        return QWebHistoryItem()
    def backItem(self):
        '''QWebHistoryItem QWebHistory.backItem()'''
        return QWebHistoryItem()
    def goToItem(self, item):
        '''void QWebHistory.goToItem(QWebHistoryItem item)'''
    def forward(self):
        '''void QWebHistory.forward()'''
    def back(self):
        '''void QWebHistory.back()'''
    def canGoForward(self):
        '''bool QWebHistory.canGoForward()'''
        return bool()
    def canGoBack(self):
        '''bool QWebHistory.canGoBack()'''
        return bool()
    def forwardItems(self, maxItems):
        '''list-of-QWebHistoryItem QWebHistory.forwardItems(int maxItems)'''
        return [QWebHistoryItem()]
    def backItems(self, maxItems):
        '''list-of-QWebHistoryItem QWebHistory.backItems(int maxItems)'''
        return [QWebHistoryItem()]
    def items(self):
        '''list-of-QWebHistoryItem QWebHistory.items()'''
        return [QWebHistoryItem()]
    def clear(self):
        '''void QWebHistory.clear()'''


class QWebHistoryInterface(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QWebHistoryInterface.__init__(QObject parent = None)'''
    def addHistoryEntry(self, url):
        '''abstract void QWebHistoryInterface.addHistoryEntry(QString url)'''
    def historyContains(self, url):
        '''abstract bool QWebHistoryInterface.historyContains(QString url)'''
        return bool()
    def defaultInterface(self):
        '''static QWebHistoryInterface QWebHistoryInterface.defaultInterface()'''
        return QWebHistoryInterface()
    def setDefaultInterface(self, defaultInterface):
        '''static void QWebHistoryInterface.setDefaultInterface(QWebHistoryInterface defaultInterface)'''


class QWebInspector(QWidget):
    """"""
    def __init__(self, parent = None):
        '''void QWebInspector.__init__(QWidget parent = None)'''
    def closeEvent(self, event):
        '''void QWebInspector.closeEvent(QCloseEvent event)'''
    def hideEvent(self, event):
        '''void QWebInspector.hideEvent(QHideEvent event)'''
    def showEvent(self, event):
        '''void QWebInspector.showEvent(QShowEvent event)'''
    def resizeEvent(self, event):
        '''void QWebInspector.resizeEvent(QResizeEvent event)'''
    def event(self):
        '''QEvent QWebInspector.event()'''
        return QEvent()
    def sizeHint(self):
        '''QSize QWebInspector.sizeHint()'''
        return QSize()
    def page(self):
        '''QWebPage QWebInspector.page()'''
        return QWebPage()
    def setPage(self, page):
        '''void QWebInspector.setPage(QWebPage page)'''


class QWebPage(QObject):
    """"""
    # Enum QWebPage.Feature
    Notifications = 0
    Geolocation = 0

    # Enum QWebPage.PermissionPolicy
    PermissionUnknown = 0
    PermissionGrantedByUser = 0
    PermissionDeniedByUser = 0

    # Enum QWebPage.ErrorDomain
    QtNetwork = 0
    Http = 0
    WebKit = 0

    # Enum QWebPage.Extension
    ChooseMultipleFilesExtension = 0
    ErrorPageExtension = 0

    # Enum QWebPage.WebWindowType
    WebBrowserWindow = 0
    WebModalDialog = 0

    # Enum QWebPage.LinkDelegationPolicy
    DontDelegateLinks = 0
    DelegateExternalLinks = 0
    DelegateAllLinks = 0

    # Enum QWebPage.FindFlag
    FindBackward = 0
    FindCaseSensitively = 0
    FindWrapsAroundDocument = 0
    HighlightAllOccurrences = 0

    # Enum QWebPage.WebAction
    NoWebAction = 0
    OpenLink = 0
    OpenLinkInNewWindow = 0
    OpenFrameInNewWindow = 0
    DownloadLinkToDisk = 0
    CopyLinkToClipboard = 0
    OpenImageInNewWindow = 0
    DownloadImageToDisk = 0
    CopyImageToClipboard = 0
    Back = 0
    Forward = 0
    Stop = 0
    Reload = 0
    Cut = 0
    Copy = 0
    Paste = 0
    Undo = 0
    Redo = 0
    MoveToNextChar = 0
    MoveToPreviousChar = 0
    MoveToNextWord = 0
    MoveToPreviousWord = 0
    MoveToNextLine = 0
    MoveToPreviousLine = 0
    MoveToStartOfLine = 0
    MoveToEndOfLine = 0
    MoveToStartOfBlock = 0
    MoveToEndOfBlock = 0
    MoveToStartOfDocument = 0
    MoveToEndOfDocument = 0
    SelectNextChar = 0
    SelectPreviousChar = 0
    SelectNextWord = 0
    SelectPreviousWord = 0
    SelectNextLine = 0
    SelectPreviousLine = 0
    SelectStartOfLine = 0
    SelectEndOfLine = 0
    SelectStartOfBlock = 0
    SelectEndOfBlock = 0
    SelectStartOfDocument = 0
    SelectEndOfDocument = 0
    DeleteStartOfWord = 0
    DeleteEndOfWord = 0
    SetTextDirectionDefault = 0
    SetTextDirectionLeftToRight = 0
    SetTextDirectionRightToLeft = 0
    ToggleBold = 0
    ToggleItalic = 0
    ToggleUnderline = 0
    InspectElement = 0
    InsertParagraphSeparator = 0
    InsertLineSeparator = 0
    SelectAll = 0
    ReloadAndBypassCache = 0
    PasteAndMatchStyle = 0
    RemoveFormat = 0
    ToggleStrikethrough = 0
    ToggleSubscript = 0
    ToggleSuperscript = 0
    InsertUnorderedList = 0
    InsertOrderedList = 0
    Indent = 0
    Outdent = 0
    AlignCenter = 0
    AlignJustified = 0
    AlignLeft = 0
    AlignRight = 0
    StopScheduledPageRefresh = 0
    CopyImageUrlToClipboard = 0

    # Enum QWebPage.NavigationType
    NavigationTypeLinkClicked = 0
    NavigationTypeFormSubmitted = 0
    NavigationTypeBackOrForward = 0
    NavigationTypeReload = 0
    NavigationTypeFormResubmitted = 0
    NavigationTypeOther = 0

    def __init__(self, parent = None):
        '''void QWebPage.__init__(QObject parent = None)'''
    featurePermissionRequestCanceled = pyqtSignal() # void featurePermissionRequestCanceled(QWebFrame *,QWebPage::Feature) - signal
    featurePermissionRequested = pyqtSignal() # void featurePermissionRequested(QWebFrame *,QWebPage::Feature) - signal
    viewportChangeRequested = pyqtSignal() # void viewportChangeRequested() - signal
    applicationCacheQuotaExceeded = pyqtSignal() # void applicationCacheQuotaExceeded(QWebSecurityOrigin *,quint64) - signal
    def supportsContentType(self, mimeType):
        '''bool QWebPage.supportsContentType(QString mimeType)'''
        return bool()
    def supportedContentTypes(self):
        '''QStringList QWebPage.supportedContentTypes()'''
        return QStringList()
    def setFeaturePermission(self, frame, feature, policy):
        '''void QWebPage.setFeaturePermission(QWebFrame frame, QWebPage.Feature feature, QWebPage.PermissionPolicy policy)'''
    def setActualVisibleContentRect(self, rect):
        '''void QWebPage.setActualVisibleContentRect(QRect rect)'''
    def viewportAttributesForSize(self, availableSize):
        '''QWebPage.ViewportAttributes QWebPage.viewportAttributesForSize(QSize availableSize)'''
        return QWebPage.ViewportAttributes()
    def selectedHtml(self):
        '''QString QWebPage.selectedHtml()'''
        return QString()
    def hasSelection(self):
        '''bool QWebPage.hasSelection()'''
        return bool()
    def shouldInterruptJavaScript(self):
        '''bool QWebPage.shouldInterruptJavaScript()'''
        return bool()
    def setPreferredContentsSize(self, size):
        '''void QWebPage.setPreferredContentsSize(QSize size)'''
    def preferredContentsSize(self):
        '''QSize QWebPage.preferredContentsSize()'''
        return QSize()
    def frameAt(self, pos):
        '''QWebFrame QWebPage.frameAt(QPoint pos)'''
        return QWebFrame()
    restoreFrameStateRequested = pyqtSignal() # void restoreFrameStateRequested(QWebFrame *) - signal
    saveFrameStateRequested = pyqtSignal() # void saveFrameStateRequested(QWebFrame *,QWebHistoryItem *) - signal
    databaseQuotaExceeded = pyqtSignal() # void databaseQuotaExceeded(QWebFrame *,QString) - signal
    contentsChanged = pyqtSignal() # void contentsChanged() - signal
    def createStandardContextMenu(self):
        '''QMenu QWebPage.createStandardContextMenu()'''
        return QMenu()
    def isContentEditable(self):
        '''bool QWebPage.isContentEditable()'''
        return bool()
    def setContentEditable(self, editable):
        '''void QWebPage.setContentEditable(bool editable)'''
    def userAgentForUrl(self, url):
        '''QString QWebPage.userAgentForUrl(QUrl url)'''
        return QString()
    def javaScriptConsoleMessage(self, message, lineNumber, sourceID):
        '''void QWebPage.javaScriptConsoleMessage(QString message, int lineNumber, QString sourceID)'''
    def javaScriptPrompt(self, originatingFrame, msg, defaultValue, result):
        '''bool QWebPage.javaScriptPrompt(QWebFrame originatingFrame, QString msg, QString defaultValue, QString result)'''
        return bool()
    def javaScriptPrompt(self, originatingFrame, msg, defaultValue, result):
        '''bool QWebPage.javaScriptPrompt(QWebFrame originatingFrame, QString msg, QString defaultValue, QString result)'''
        return bool()
    def javaScriptConfirm(self, originatingFrame, msg):
        '''bool QWebPage.javaScriptConfirm(QWebFrame originatingFrame, QString msg)'''
        return bool()
    def javaScriptAlert(self, originatingFrame, msg):
        '''void QWebPage.javaScriptAlert(QWebFrame originatingFrame, QString msg)'''
    def chooseFile(self, originatingFrame, oldFile):
        '''QString QWebPage.chooseFile(QWebFrame originatingFrame, QString oldFile)'''
        return QString()
    def acceptNavigationRequest(self, frame, request, type):
        '''bool QWebPage.acceptNavigationRequest(QWebFrame frame, QNetworkRequest request, QWebPage.NavigationType type)'''
        return bool()
    def createPlugin(self, classid, url, paramNames, paramValues):
        '''QObject QWebPage.createPlugin(QString classid, QUrl url, QStringList paramNames, QStringList paramValues)'''
        return QObject()
    def createWindow(self, type):
        '''QWebPage QWebPage.createWindow(QWebPage.WebWindowType type)'''
        return QWebPage()
    microFocusChanged = pyqtSignal() # void microFocusChanged() - signal
    downloadRequested = pyqtSignal() # void downloadRequested(const QNetworkRequestamp;) - signal
    unsupportedContent = pyqtSignal() # void unsupportedContent(QNetworkReply *) - signal
    menuBarVisibilityChangeRequested = pyqtSignal() # void menuBarVisibilityChangeRequested(bool) - signal
    statusBarVisibilityChangeRequested = pyqtSignal() # void statusBarVisibilityChangeRequested(bool) - signal
    toolBarVisibilityChangeRequested = pyqtSignal() # void toolBarVisibilityChangeRequested(bool) - signal
    linkClicked = pyqtSignal() # void linkClicked(const QUrlamp;) - signal
    printRequested = pyqtSignal() # void printRequested(QWebFrame *) - signal
    windowCloseRequested = pyqtSignal() # void windowCloseRequested() - signal
    scrollRequested = pyqtSignal() # void scrollRequested(int,int,const QRectamp;) - signal
    repaintRequested = pyqtSignal() # void repaintRequested(const QRectamp;) - signal
    geometryChangeRequested = pyqtSignal() # void geometryChangeRequested(const QRectamp;) - signal
    frameCreated = pyqtSignal() # void frameCreated(QWebFrame *) - signal
    selectionChanged = pyqtSignal() # void selectionChanged() - signal
    statusBarMessage = pyqtSignal() # void statusBarMessage(const QStringamp;) - signal
    linkHovered = pyqtSignal() # void linkHovered(const QStringamp;,const QStringamp;,const QStringamp;) - signal
    loadStarted = pyqtSignal() # void loadStarted() - signal
    loadProgress = pyqtSignal() # void loadProgress(int) - signal
    loadFinished = pyqtSignal() # void loadFinished(bool) - signal
    def supportsExtension(self, extension):
        '''bool QWebPage.supportsExtension(QWebPage.Extension extension)'''
        return bool()
    def extension(self, extension, option = None, output = None):
        '''bool QWebPage.extension(QWebPage.Extension extension, QWebPage.ExtensionOption option = None, QWebPage.ExtensionReturn output = None)'''
        return bool()
    def updatePositionDependentActions(self, pos):
        '''void QWebPage.updatePositionDependentActions(QPoint pos)'''
    def swallowContextMenuEvent(self, event):
        '''bool QWebPage.swallowContextMenuEvent(QContextMenuEvent event)'''
        return bool()
    def palette(self):
        '''QPalette QWebPage.palette()'''
        return QPalette()
    def setPalette(self, palette):
        '''void QWebPage.setPalette(QPalette palette)'''
    def linkDelegationPolicy(self):
        '''QWebPage.LinkDelegationPolicy QWebPage.linkDelegationPolicy()'''
        return QWebPage.LinkDelegationPolicy()
    def setLinkDelegationPolicy(self, policy):
        '''void QWebPage.setLinkDelegationPolicy(QWebPage.LinkDelegationPolicy policy)'''
    def forwardUnsupportedContent(self):
        '''bool QWebPage.forwardUnsupportedContent()'''
        return bool()
    def setForwardUnsupportedContent(self, forward):
        '''void QWebPage.setForwardUnsupportedContent(bool forward)'''
    def findText(self, subString, options = 0):
        '''bool QWebPage.findText(QString subString, QWebPage.FindFlags options = 0)'''
        return bool()
    def inputMethodQuery(self, property):
        '''QVariant QWebPage.inputMethodQuery(Qt.InputMethodQuery property)'''
        return QVariant()
    def focusNextPrevChild(self, next):
        '''bool QWebPage.focusNextPrevChild(bool next)'''
        return bool()
    def event(self):
        '''QEvent QWebPage.event()'''
        return QEvent()
    def setViewportSize(self, size):
        '''void QWebPage.setViewportSize(QSize size)'''
    def viewportSize(self):
        '''QSize QWebPage.viewportSize()'''
        return QSize()
    def triggerAction(self, action, checked = False):
        '''void QWebPage.triggerAction(QWebPage.WebAction action, bool checked = False)'''
    def action(self, action):
        '''QAction QWebPage.action(QWebPage.WebAction action)'''
        return QAction()
    def selectedText(self):
        '''QString QWebPage.selectedText()'''
        return QString()
    def bytesReceived(self):
        '''int QWebPage.bytesReceived()'''
        return int()
    def totalBytes(self):
        '''int QWebPage.totalBytes()'''
        return int()
    def pluginFactory(self):
        '''QWebPluginFactory QWebPage.pluginFactory()'''
        return QWebPluginFactory()
    def setPluginFactory(self, factory):
        '''void QWebPage.setPluginFactory(QWebPluginFactory factory)'''
    def networkAccessManager(self):
        '''QNetworkAccessManager QWebPage.networkAccessManager()'''
        return QNetworkAccessManager()
    def setNetworkAccessManager(self, manager):
        '''void QWebPage.setNetworkAccessManager(QNetworkAccessManager manager)'''
    def undoStack(self):
        '''QUndoStack QWebPage.undoStack()'''
        return QUndoStack()
    def isModified(self):
        '''bool QWebPage.isModified()'''
        return bool()
    def view(self):
        '''QWidget QWebPage.view()'''
        return QWidget()
    def setView(self, view):
        '''void QWebPage.setView(QWidget view)'''
    def settings(self):
        '''QWebSettings QWebPage.settings()'''
        return QWebSettings()
    def history(self):
        '''QWebHistory QWebPage.history()'''
        return QWebHistory()
    def currentFrame(self):
        '''QWebFrame QWebPage.currentFrame()'''
        return QWebFrame()
    def mainFrame(self):
        '''QWebFrame QWebPage.mainFrame()'''
        return QWebFrame()
    class ViewportAttributes():
        """"""
        def __init__(self):
            '''void QWebPage.ViewportAttributes.__init__()'''
        def __init__(self, other):
            '''void QWebPage.ViewportAttributes.__init__(QWebPage.ViewportAttributes other)'''
        def size(self):
            '''QSize QWebPage.ViewportAttributes.size()'''
            return QSize()
        def isValid(self):
            '''bool QWebPage.ViewportAttributes.isValid()'''
            return bool()
        def isUserScalable(self):
            '''bool QWebPage.ViewportAttributes.isUserScalable()'''
            return bool()
        def devicePixelRatio(self):
            '''float QWebPage.ViewportAttributes.devicePixelRatio()'''
            return float()
        def maximumScaleFactor(self):
            '''float QWebPage.ViewportAttributes.maximumScaleFactor()'''
            return float()
        def minimumScaleFactor(self):
            '''float QWebPage.ViewportAttributes.minimumScaleFactor()'''
            return float()
        def initialScaleFactor(self):
            '''float QWebPage.ViewportAttributes.initialScaleFactor()'''
            return float()
    class ChooseMultipleFilesExtensionOption(QWebPage.ExtensionOption):
        """"""
        parentFrame = None # QWebFrame - member
        suggestedFileNames = None # QStringList - member
        def __init__(self):
            '''void QWebPage.ChooseMultipleFilesExtensionOption.__init__()'''
        def __init__(self):
            '''QWebPage.ChooseMultipleFilesExtensionOption QWebPage.ChooseMultipleFilesExtensionOption.__init__()'''
            return QWebPage.ChooseMultipleFilesExtensionOption()
    class FindFlags():
        """"""
        def __init__(self):
            '''QWebPage.FindFlags QWebPage.FindFlags.__init__()'''
            return QWebPage.FindFlags()
        def __init__(self):
            '''int QWebPage.FindFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QWebPage.FindFlags.__init__()'''
        def __bool__(self):
            '''int QWebPage.FindFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QWebPage.FindFlags.__ne__(QWebPage.FindFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QWebPage.FindFlags.__eq__(QWebPage.FindFlags f)'''
            return bool()
        def __invert__(self):
            '''QWebPage.FindFlags QWebPage.FindFlags.__invert__()'''
            return QWebPage.FindFlags()
        def __and__(self, mask):
            '''QWebPage.FindFlags QWebPage.FindFlags.__and__(int mask)'''
            return QWebPage.FindFlags()
        def __xor__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__xor__(QWebPage.FindFlags f)'''
            return QWebPage.FindFlags()
        def __xor__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__xor__(int f)'''
            return QWebPage.FindFlags()
        def __or__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__or__(QWebPage.FindFlags f)'''
            return QWebPage.FindFlags()
        def __or__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__or__(int f)'''
            return QWebPage.FindFlags()
        def __int__(self):
            '''int QWebPage.FindFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__ixor__(QWebPage.FindFlags f)'''
            return QWebPage.FindFlags()
        def __ior__(self, f):
            '''QWebPage.FindFlags QWebPage.FindFlags.__ior__(QWebPage.FindFlags f)'''
            return QWebPage.FindFlags()
        def __iand__(self, mask):
            '''QWebPage.FindFlags QWebPage.FindFlags.__iand__(int mask)'''
            return QWebPage.FindFlags()
    class ErrorPageExtensionOption(QWebPage.ExtensionOption):
        """"""
        domain = None # QWebPage.ErrorDomain - member
        error = None # int - member
        errorString = None # QString - member
        frame = None # QWebFrame - member
        url = None # QUrl - member
        def __init__(self):
            '''void QWebPage.ErrorPageExtensionOption.__init__()'''
        def __init__(self):
            '''QWebPage.ErrorPageExtensionOption QWebPage.ErrorPageExtensionOption.__init__()'''
            return QWebPage.ErrorPageExtensionOption()
    class ErrorPageExtensionReturn(QWebPage.ExtensionReturn):
        """"""
        baseUrl = None # QUrl - member
        content = None # QByteArray - member
        contentType = None # QString - member
        encoding = None # QString - member
        def __init__(self):
            '''void QWebPage.ErrorPageExtensionReturn.__init__()'''
        def __init__(self):
            '''QWebPage.ErrorPageExtensionReturn QWebPage.ErrorPageExtensionReturn.__init__()'''
            return QWebPage.ErrorPageExtensionReturn()
    class ExtensionOption():
        """"""
        def __init__(self):
            '''void QWebPage.ExtensionOption.__init__()'''
        def __init__(self):
            '''QWebPage.ExtensionOption QWebPage.ExtensionOption.__init__()'''
            return QWebPage.ExtensionOption()
    class ExtensionReturn():
        """"""
        def __init__(self):
            '''void QWebPage.ExtensionReturn.__init__()'''
        def __init__(self):
            '''QWebPage.ExtensionReturn QWebPage.ExtensionReturn.__init__()'''
            return QWebPage.ExtensionReturn()
    class ChooseMultipleFilesExtensionReturn(QWebPage.ExtensionReturn):
        """"""
        fileNames = None # QStringList - member
        def __init__(self):
            '''void QWebPage.ChooseMultipleFilesExtensionReturn.__init__()'''
        def __init__(self):
            '''QWebPage.ChooseMultipleFilesExtensionReturn QWebPage.ChooseMultipleFilesExtensionReturn.__init__()'''
            return QWebPage.ChooseMultipleFilesExtensionReturn()


class QWebPluginFactory(QObject):
    """"""
    # Enum QWebPluginFactory.Extension

    def __init__(self, parent = None):
        '''void QWebPluginFactory.__init__(QObject parent = None)'''
    def supportsExtension(self, extension):
        '''bool QWebPluginFactory.supportsExtension(QWebPluginFactory.Extension extension)'''
        return bool()
    def extension(self, extension, option = None, output = None):
        '''bool QWebPluginFactory.extension(QWebPluginFactory.Extension extension, QWebPluginFactory.ExtensionOption option = None, QWebPluginFactory.ExtensionReturn output = None)'''
        return bool()
    def create(self, mimeType, url, argumentNames, argumentValues):
        '''abstract QObject QWebPluginFactory.create(QString mimeType, QUrl url, QStringList argumentNames, QStringList argumentValues)'''
        return QObject()
    def refreshPlugins(self):
        '''void QWebPluginFactory.refreshPlugins()'''
    def plugins(self):
        '''abstract list-of-QWebPluginFactory.Plugin QWebPluginFactory.plugins()'''
        return [QWebPluginFactory.Plugin()]
    class ExtensionOption():
        """"""
        def __init__(self):
            '''void QWebPluginFactory.ExtensionOption.__init__()'''
        def __init__(self):
            '''QWebPluginFactory.ExtensionOption QWebPluginFactory.ExtensionOption.__init__()'''
            return QWebPluginFactory.ExtensionOption()
    class ExtensionReturn():
        """"""
        def __init__(self):
            '''void QWebPluginFactory.ExtensionReturn.__init__()'''
        def __init__(self):
            '''QWebPluginFactory.ExtensionReturn QWebPluginFactory.ExtensionReturn.__init__()'''
            return QWebPluginFactory.ExtensionReturn()
    class Plugin():
        """"""
        description = None # QString - member
        mimeTypes = None # list-of-QWebPluginFactory.MimeType - member
        name = None # QString - member
        def __init__(self):
            '''void QWebPluginFactory.Plugin.__init__()'''
        def __init__(self):
            '''QWebPluginFactory.Plugin QWebPluginFactory.Plugin.__init__()'''
            return QWebPluginFactory.Plugin()
    class MimeType():
        """"""
        description = None # QString - member
        fileExtensions = None # QStringList - member
        name = None # QString - member
        def __init__(self):
            '''void QWebPluginFactory.MimeType.__init__()'''
        def __init__(self):
            '''QWebPluginFactory.MimeType QWebPluginFactory.MimeType.__init__()'''
            return QWebPluginFactory.MimeType()
        def __ne__(self, other):
            '''bool QWebPluginFactory.MimeType.__ne__(QWebPluginFactory.MimeType other)'''
            return bool()
        def __eq__(self, other):
            '''bool QWebPluginFactory.MimeType.__eq__(QWebPluginFactory.MimeType other)'''
            return bool()


class QWebSecurityOrigin():
    """"""
    def __init__(self, other):
        '''void QWebSecurityOrigin.__init__(QWebSecurityOrigin other)'''
    def setApplicationCacheQuota(self, quota):
        '''void QWebSecurityOrigin.setApplicationCacheQuota(int quota)'''
    def localSchemes(self):
        '''static QStringList QWebSecurityOrigin.localSchemes()'''
        return QStringList()
    def removeLocalScheme(self, scheme):
        '''static void QWebSecurityOrigin.removeLocalScheme(QString scheme)'''
    def addLocalScheme(self, scheme):
        '''static void QWebSecurityOrigin.addLocalScheme(QString scheme)'''
    def databases(self):
        '''list-of-QWebDatabase QWebSecurityOrigin.databases()'''
        return [QWebDatabase()]
    def setDatabaseQuota(self, quota):
        '''void QWebSecurityOrigin.setDatabaseQuota(int quota)'''
    def databaseQuota(self):
        '''int QWebSecurityOrigin.databaseQuota()'''
        return int()
    def databaseUsage(self):
        '''int QWebSecurityOrigin.databaseUsage()'''
        return int()
    def port(self):
        '''int QWebSecurityOrigin.port()'''
        return int()
    def host(self):
        '''QString QWebSecurityOrigin.host()'''
        return QString()
    def scheme(self):
        '''QString QWebSecurityOrigin.scheme()'''
        return QString()
    def allOrigins(self):
        '''static list-of-QWebSecurityOrigin QWebSecurityOrigin.allOrigins()'''
        return [QWebSecurityOrigin()]


class QWebSettings():
    """"""
    # Enum QWebSettings.FontSize
    MinimumFontSize = 0
    MinimumLogicalFontSize = 0
    DefaultFontSize = 0
    DefaultFixedFontSize = 0

    # Enum QWebSettings.WebGraphic
    MissingImageGraphic = 0
    MissingPluginGraphic = 0
    DefaultFrameIconGraphic = 0
    TextAreaSizeGripCornerGraphic = 0
    InputSpeechButtonGraphic = 0
    SearchCancelButtonGraphic = 0
    SearchCancelButtonPressedGraphic = 0

    # Enum QWebSettings.WebAttribute
    AutoLoadImages = 0
    JavascriptEnabled = 0
    JavaEnabled = 0
    PluginsEnabled = 0
    PrivateBrowsingEnabled = 0
    JavascriptCanOpenWindows = 0
    JavascriptCanCloseWindows = 0
    JavascriptCanAccessClipboard = 0
    DeveloperExtrasEnabled = 0
    LinksIncludedInFocusChain = 0
    ZoomTextOnly = 0
    PrintElementBackgrounds = 0
    OfflineStorageDatabaseEnabled = 0
    OfflineWebApplicationCacheEnabled = 0
    LocalStorageDatabaseEnabled = 0
    LocalStorageEnabled = 0
    LocalContentCanAccessRemoteUrls = 0
    DnsPrefetchEnabled = 0
    XSSAuditingEnabled = 0
    AcceleratedCompositingEnabled = 0
    SpatialNavigationEnabled = 0
    LocalContentCanAccessFileUrls = 0
    TiledBackingStoreEnabled = 0
    FrameFlatteningEnabled = 0
    SiteSpecificQuirksEnabled = 0
    WebGLEnabled = 0
    HyperlinkAuditingEnabled = 0

    # Enum QWebSettings.FontFamily
    StandardFont = 0
    FixedFont = 0
    SerifFont = 0
    SansSerifFont = 0
    CursiveFont = 0
    FantasyFont = 0

    def enablePersistentStorage(self, path = QString()):
        '''static void QWebSettings.enablePersistentStorage(QString path = QString())'''
    def clearMemoryCaches(self):
        '''static void QWebSettings.clearMemoryCaches()'''
    def localStoragePath(self):
        '''QString QWebSettings.localStoragePath()'''
        return QString()
    def setLocalStoragePath(self, path):
        '''void QWebSettings.setLocalStoragePath(QString path)'''
    def offlineWebApplicationCacheQuota(self):
        '''static int QWebSettings.offlineWebApplicationCacheQuota()'''
        return int()
    def setOfflineWebApplicationCacheQuota(self, maximumSize):
        '''static void QWebSettings.setOfflineWebApplicationCacheQuota(int maximumSize)'''
    def offlineWebApplicationCachePath(self):
        '''static QString QWebSettings.offlineWebApplicationCachePath()'''
        return QString()
    def setOfflineWebApplicationCachePath(self, path):
        '''static void QWebSettings.setOfflineWebApplicationCachePath(QString path)'''
    def defaultTextEncoding(self):
        '''QString QWebSettings.defaultTextEncoding()'''
        return QString()
    def setDefaultTextEncoding(self, encoding):
        '''void QWebSettings.setDefaultTextEncoding(QString encoding)'''
    def offlineStorageDefaultQuota(self):
        '''static int QWebSettings.offlineStorageDefaultQuota()'''
        return int()
    def setOfflineStorageDefaultQuota(self, maximumSize):
        '''static void QWebSettings.setOfflineStorageDefaultQuota(int maximumSize)'''
    def offlineStoragePath(self):
        '''static QString QWebSettings.offlineStoragePath()'''
        return QString()
    def setOfflineStoragePath(self, path):
        '''static void QWebSettings.setOfflineStoragePath(QString path)'''
    def setObjectCacheCapacities(self, cacheMinDeadCapacity, cacheMaxDead, totalCapacity):
        '''static void QWebSettings.setObjectCacheCapacities(int cacheMinDeadCapacity, int cacheMaxDead, int totalCapacity)'''
    def maximumPagesInCache(self):
        '''static int QWebSettings.maximumPagesInCache()'''
        return int()
    def setMaximumPagesInCache(self, pages):
        '''static void QWebSettings.setMaximumPagesInCache(int pages)'''
    def webGraphic(self, type):
        '''static QPixmap QWebSettings.webGraphic(QWebSettings.WebGraphic type)'''
        return QPixmap()
    def setWebGraphic(self, type, graphic):
        '''static void QWebSettings.setWebGraphic(QWebSettings.WebGraphic type, QPixmap graphic)'''
    def iconForUrl(self, url):
        '''static QIcon QWebSettings.iconForUrl(QUrl url)'''
        return QIcon()
    def clearIconDatabase(self):
        '''static void QWebSettings.clearIconDatabase()'''
    def iconDatabasePath(self):
        '''static QString QWebSettings.iconDatabasePath()'''
        return QString()
    def setIconDatabasePath(self, location):
        '''static void QWebSettings.setIconDatabasePath(QString location)'''
    def userStyleSheetUrl(self):
        '''QUrl QWebSettings.userStyleSheetUrl()'''
        return QUrl()
    def setUserStyleSheetUrl(self, location):
        '''void QWebSettings.setUserStyleSheetUrl(QUrl location)'''
    def resetAttribute(self, attr):
        '''void QWebSettings.resetAttribute(QWebSettings.WebAttribute attr)'''
    def testAttribute(self, attr):
        '''bool QWebSettings.testAttribute(QWebSettings.WebAttribute attr)'''
        return bool()
    def setAttribute(self, attr, on):
        '''void QWebSettings.setAttribute(QWebSettings.WebAttribute attr, bool on)'''
    def resetFontSize(self, type):
        '''void QWebSettings.resetFontSize(QWebSettings.FontSize type)'''
    def fontSize(self, type):
        '''int QWebSettings.fontSize(QWebSettings.FontSize type)'''
        return int()
    def setFontSize(self, type, size):
        '''void QWebSettings.setFontSize(QWebSettings.FontSize type, int size)'''
    def resetFontFamily(self, which):
        '''void QWebSettings.resetFontFamily(QWebSettings.FontFamily which)'''
    def fontFamily(self, which):
        '''QString QWebSettings.fontFamily(QWebSettings.FontFamily which)'''
        return QString()
    def setFontFamily(self, which, family):
        '''void QWebSettings.setFontFamily(QWebSettings.FontFamily which, QString family)'''
    def globalSettings(self):
        '''static QWebSettings QWebSettings.globalSettings()'''
        return QWebSettings()


class QWebView(QWidget):
    """"""
    def __init__(self, parent = None):
        '''void QWebView.__init__(QWidget parent = None)'''
    def selectedHtml(self):
        '''QString QWebView.selectedHtml()'''
        return QString()
    def hasSelection(self):
        '''bool QWebView.hasSelection()'''
        return bool()
    def setRenderHint(self, hint, enabled = True):
        '''void QWebView.setRenderHint(QPainter.RenderHint hint, bool enabled = True)'''
    def setRenderHints(self, hints):
        '''void QWebView.setRenderHints(QPainter.RenderHints hints)'''
    def renderHints(self):
        '''QPainter.RenderHints QWebView.renderHints()'''
        return QPainter.RenderHints()
    def setZoomFactor(self, factor):
        '''void QWebView.setZoomFactor(float factor)'''
    def zoomFactor(self):
        '''float QWebView.zoomFactor()'''
        return float()
    def focusNextPrevChild(self, next):
        '''bool QWebView.focusNextPrevChild(bool next)'''
        return bool()
    def inputMethodEvent(self):
        '''QInputMethodEvent QWebView.inputMethodEvent()'''
        return QInputMethodEvent()
    def focusOutEvent(self):
        '''QFocusEvent QWebView.focusOutEvent()'''
        return QFocusEvent()
    def focusInEvent(self):
        '''QFocusEvent QWebView.focusInEvent()'''
        return QFocusEvent()
    def dropEvent(self):
        '''QDropEvent QWebView.dropEvent()'''
        return QDropEvent()
    def dragMoveEvent(self):
        '''QDragMoveEvent QWebView.dragMoveEvent()'''
        return QDragMoveEvent()
    def dragLeaveEvent(self):
        '''QDragLeaveEvent QWebView.dragLeaveEvent()'''
        return QDragLeaveEvent()
    def dragEnterEvent(self):
        '''QDragEnterEvent QWebView.dragEnterEvent()'''
        return QDragEnterEvent()
    def keyReleaseEvent(self):
        '''QKeyEvent QWebView.keyReleaseEvent()'''
        return QKeyEvent()
    def keyPressEvent(self):
        '''QKeyEvent QWebView.keyPressEvent()'''
        return QKeyEvent()
    def wheelEvent(self):
        '''QWheelEvent QWebView.wheelEvent()'''
        return QWheelEvent()
    def contextMenuEvent(self):
        '''QContextMenuEvent QWebView.contextMenuEvent()'''
        return QContextMenuEvent()
    def mouseReleaseEvent(self):
        '''QMouseEvent QWebView.mouseReleaseEvent()'''
        return QMouseEvent()
    def mouseDoubleClickEvent(self):
        '''QMouseEvent QWebView.mouseDoubleClickEvent()'''
        return QMouseEvent()
    def mousePressEvent(self):
        '''QMouseEvent QWebView.mousePressEvent()'''
        return QMouseEvent()
    def mouseMoveEvent(self):
        '''QMouseEvent QWebView.mouseMoveEvent()'''
        return QMouseEvent()
    def changeEvent(self):
        '''QEvent QWebView.changeEvent()'''
        return QEvent()
    def paintEvent(self, ev):
        '''void QWebView.paintEvent(QPaintEvent ev)'''
    def resizeEvent(self, e):
        '''void QWebView.resizeEvent(QResizeEvent e)'''
    def createWindow(self, type):
        '''QWebView QWebView.createWindow(QWebPage.WebWindowType type)'''
        return QWebView()
    urlChanged = pyqtSignal() # void urlChanged(const QUrlamp;) - signal
    iconChanged = pyqtSignal() # void iconChanged() - signal
    selectionChanged = pyqtSignal() # void selectionChanged() - signal
    linkClicked = pyqtSignal() # void linkClicked(const QUrlamp;) - signal
    statusBarMessage = pyqtSignal() # void statusBarMessage(const QStringamp;) - signal
    titleChanged = pyqtSignal() # void titleChanged(const QStringamp;) - signal
    loadFinished = pyqtSignal() # void loadFinished(bool) - signal
    loadProgress = pyqtSignal() # void loadProgress(int) - signal
    loadStarted = pyqtSignal() # void loadStarted() - signal
    def print_(self, printer):
        '''void QWebView.print_(QPrinter printer)'''
    def reload(self):
        '''void QWebView.reload()'''
    def forward(self):
        '''void QWebView.forward()'''
    def back(self):
        '''void QWebView.back()'''
    def stop(self):
        '''void QWebView.stop()'''
    def event(self):
        '''QEvent QWebView.event()'''
        return QEvent()
    def findText(self, subString, options = 0):
        '''bool QWebView.findText(QString subString, QWebPage.FindFlags options = 0)'''
        return bool()
    def textSizeMultiplier(self):
        '''float QWebView.textSizeMultiplier()'''
        return float()
    def setTextSizeMultiplier(self, factor):
        '''void QWebView.setTextSizeMultiplier(float factor)'''
    def sizeHint(self):
        '''QSize QWebView.sizeHint()'''
        return QSize()
    def inputMethodQuery(self, property):
        '''QVariant QWebView.inputMethodQuery(Qt.InputMethodQuery property)'''
        return QVariant()
    def isModified(self):
        '''bool QWebView.isModified()'''
        return bool()
    def triggerPageAction(self, action, checked = False):
        '''void QWebView.triggerPageAction(QWebPage.WebAction action, bool checked = False)'''
    def pageAction(self, action):
        '''QAction QWebView.pageAction(QWebPage.WebAction action)'''
        return QAction()
    def selectedText(self):
        '''QString QWebView.selectedText()'''
        return QString()
    def icon(self):
        '''QIcon QWebView.icon()'''
        return QIcon()
    def url(self):
        '''QUrl QWebView.url()'''
        return QUrl()
    def setUrl(self, url):
        '''void QWebView.setUrl(QUrl url)'''
    def title(self):
        '''QString QWebView.title()'''
        return QString()
    def settings(self):
        '''QWebSettings QWebView.settings()'''
        return QWebSettings()
    def history(self):
        '''QWebHistory QWebView.history()'''
        return QWebHistory()
    def setContent(self, data, mimeType = QString(), baseUrl = QUrl()):
        '''void QWebView.setContent(QByteArray data, QString mimeType = QString(), QUrl baseUrl = QUrl())'''
    def setHtml(self, html, baseUrl = QUrl()):
        '''void QWebView.setHtml(QString html, QUrl baseUrl = QUrl())'''
    def load(self, url):
        '''void QWebView.load(QUrl url)'''
    def load(self, request, operation = None, body = QByteArray()):
        '''void QWebView.load(QNetworkRequest request, QNetworkAccessManager.Operation operation = QNetworkAccessManager.GetOperation, QByteArray body = QByteArray())'''
    def setPage(self, page):
        '''void QWebView.setPage(QWebPage page)'''
    def page(self):
        '''QWebPage QWebView.page()'''
        return QWebPage()


def qWebKitMinorVersion():
    '''static int qWebKitMinorVersion()'''
    return int()

def qWebKitMajorVersion():
    '''static int qWebKitMajorVersion()'''
    return int()

def qWebKitVersion():
    '''static QString qWebKitVersion()'''
    return QString()




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QBluetooth():
    """"""
    # Enum QBluetooth.Security
    NoSecurity = 0
    Authorization = 0
    Authentication = 0
    Encryption = 0
    Secure = 0

    class SecurityFlags():
        """"""
        def __init__(self):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__init__()'''
            return QBluetooth.SecurityFlags()
        def __init__(self):
            '''int QBluetooth.SecurityFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QBluetooth.SecurityFlags.__init__()'''
        def __bool__(self):
            '''int QBluetooth.SecurityFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QBluetooth.SecurityFlags.__ne__(QBluetooth.SecurityFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QBluetooth.SecurityFlags.__eq__(QBluetooth.SecurityFlags f)'''
            return bool()
        def __invert__(self):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__invert__()'''
            return QBluetooth.SecurityFlags()
        def __and__(self, mask):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__and__(int mask)'''
            return QBluetooth.SecurityFlags()
        def __xor__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__xor__(QBluetooth.SecurityFlags f)'''
            return QBluetooth.SecurityFlags()
        def __xor__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__xor__(int f)'''
            return QBluetooth.SecurityFlags()
        def __or__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__or__(QBluetooth.SecurityFlags f)'''
            return QBluetooth.SecurityFlags()
        def __or__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__or__(int f)'''
            return QBluetooth.SecurityFlags()
        def __int__(self):
            '''int QBluetooth.SecurityFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__ixor__(QBluetooth.SecurityFlags f)'''
            return QBluetooth.SecurityFlags()
        def __ior__(self, f):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__ior__(QBluetooth.SecurityFlags f)'''
            return QBluetooth.SecurityFlags()
        def __iand__(self, mask):
            '''QBluetooth.SecurityFlags QBluetooth.SecurityFlags.__iand__(int mask)'''
            return QBluetooth.SecurityFlags()


class QBluetoothAddress():
    """"""
    def __init__(self):
        '''void QBluetoothAddress.__init__()'''
    def __init__(self, address):
        '''void QBluetoothAddress.__init__(int address)'''
    def __init__(self, address):
        '''void QBluetoothAddress.__init__(str address)'''
    def __init__(self, other):
        '''void QBluetoothAddress.__init__(QBluetoothAddress other)'''
    def __ge__(self, other):
        '''bool QBluetoothAddress.__ge__(QBluetoothAddress other)'''
        return bool()
    def toString(self):
        '''str QBluetoothAddress.toString()'''
        return str()
    def toUInt64(self):
        '''int QBluetoothAddress.toUInt64()'''
        return int()
    def __ne__(self, other):
        '''bool QBluetoothAddress.__ne__(QBluetoothAddress other)'''
        return bool()
    def __eq__(self, other):
        '''bool QBluetoothAddress.__eq__(QBluetoothAddress other)'''
        return bool()
    def __lt__(self, other):
        '''bool QBluetoothAddress.__lt__(QBluetoothAddress other)'''
        return bool()
    def clear(self):
        '''void QBluetoothAddress.clear()'''
    def isNull(self):
        '''bool QBluetoothAddress.isNull()'''
        return bool()


class QBluetoothDeviceDiscoveryAgent(QObject):
    """"""
    # Enum QBluetoothDeviceDiscoveryAgent.InquiryType
    GeneralUnlimitedInquiry = 0
    LimitedInquiry = 0

    # Enum QBluetoothDeviceDiscoveryAgent.Error
    NoError = 0
    InputOutputError = 0
    PoweredOffError = 0
    InvalidBluetoothAdapterError = 0
    UnsupportedPlatformError = 0
    UnknownError = 0

    def __init__(self, parent = None):
        '''void QBluetoothDeviceDiscoveryAgent.__init__(QObject parent = None)'''
    def __init__(self, deviceAdapter, parent = None):
        '''void QBluetoothDeviceDiscoveryAgent.__init__(QBluetoothAddress deviceAdapter, QObject parent = None)'''
    canceled = pyqtSignal() # void canceled() - signal
    finished = pyqtSignal() # void finished() - signal
    deviceDiscovered = pyqtSignal() # void deviceDiscovered(const QBluetoothDeviceInfoamp;) - signal
    def stop(self):
        '''void QBluetoothDeviceDiscoveryAgent.stop()'''
    def start(self):
        '''void QBluetoothDeviceDiscoveryAgent.start()'''
    def discoveredDevices(self):
        '''list-of-QBluetoothDeviceInfo QBluetoothDeviceDiscoveryAgent.discoveredDevices()'''
        return [QBluetoothDeviceInfo()]
    def errorString(self):
        '''str QBluetoothDeviceDiscoveryAgent.errorString()'''
        return str()
    def error(self):
        '''QBluetoothDeviceDiscoveryAgent.Error QBluetoothDeviceDiscoveryAgent.error()'''
        return QBluetoothDeviceDiscoveryAgent.Error()
    error = pyqtSignal() # void error(QBluetoothDeviceDiscoveryAgent::Error) - signal
    def isActive(self):
        '''bool QBluetoothDeviceDiscoveryAgent.isActive()'''
        return bool()
    def setInquiryType(self, type):
        '''void QBluetoothDeviceDiscoveryAgent.setInquiryType(QBluetoothDeviceDiscoveryAgent.InquiryType type)'''
    def inquiryType(self):
        '''QBluetoothDeviceDiscoveryAgent.InquiryType QBluetoothDeviceDiscoveryAgent.inquiryType()'''
        return QBluetoothDeviceDiscoveryAgent.InquiryType()


class QBluetoothDeviceInfo():
    """"""
    # Enum QBluetoothDeviceInfo.CoreConfiguration
    UnknownCoreConfiguration = 0
    LowEnergyCoreConfiguration = 0
    BaseRateCoreConfiguration = 0
    BaseRateAndLowEnergyCoreConfiguration = 0

    # Enum QBluetoothDeviceInfo.DataCompleteness
    DataComplete = 0
    DataIncomplete = 0
    DataUnavailable = 0

    # Enum QBluetoothDeviceInfo.ServiceClass
    NoService = 0
    PositioningService = 0
    NetworkingService = 0
    RenderingService = 0
    CapturingService = 0
    ObjectTransferService = 0
    AudioService = 0
    TelephonyService = 0
    InformationService = 0
    AllServices = 0

    # Enum QBluetoothDeviceInfo.MinorHealthClass
    UncategorizedHealthDevice = 0
    HealthBloodPressureMonitor = 0
    HealthThermometer = 0
    HealthWeightScale = 0
    HealthGlucoseMeter = 0
    HealthPulseOximeter = 0
    HealthDataDisplay = 0
    HealthStepCounter = 0

    # Enum QBluetoothDeviceInfo.MinorToyClass
    UncategorizedToy = 0
    ToyRobot = 0
    ToyVehicle = 0
    ToyDoll = 0
    ToyController = 0
    ToyGame = 0

    # Enum QBluetoothDeviceInfo.MinorWearableClass
    UncategorizedWearableDevice = 0
    WearableWristWatch = 0
    WearablePager = 0
    WearableJacket = 0
    WearableHelmet = 0
    WearableGlasses = 0

    # Enum QBluetoothDeviceInfo.MinorImagingClass
    UncategorizedImagingDevice = 0
    ImageDisplay = 0
    ImageCamera = 0
    ImageScanner = 0
    ImagePrinter = 0

    # Enum QBluetoothDeviceInfo.MinorPeripheralClass
    UncategorizedPeripheral = 0
    KeyboardPeripheral = 0
    PointingDevicePeripheral = 0
    KeyboardWithPointingDevicePeripheral = 0
    JoystickPeripheral = 0
    GamepadPeripheral = 0
    RemoteControlPeripheral = 0
    SensingDevicePeripheral = 0
    DigitizerTabletPeripheral = 0
    CardReaderPeripheral = 0

    # Enum QBluetoothDeviceInfo.MinorAudioVideoClass
    UncategorizedAudioVideoDevice = 0
    WearableHeadsetDevice = 0
    HandsFreeDevice = 0
    Microphone = 0
    Loudspeaker = 0
    Headphones = 0
    PortableAudioDevice = 0
    CarAudio = 0
    SetTopBox = 0
    HiFiAudioDevice = 0
    Vcr = 0
    VideoCamera = 0
    Camcorder = 0
    VideoMonitor = 0
    VideoDisplayAndLoudspeaker = 0
    VideoConferencing = 0
    GamingDevice = 0

    # Enum QBluetoothDeviceInfo.MinorNetworkClass
    NetworkFullService = 0
    NetworkLoadFactorOne = 0
    NetworkLoadFactorTwo = 0
    NetworkLoadFactorThree = 0
    NetworkLoadFactorFour = 0
    NetworkLoadFactorFive = 0
    NetworkLoadFactorSix = 0
    NetworkNoService = 0

    # Enum QBluetoothDeviceInfo.MinorPhoneClass
    UncategorizedPhone = 0
    CellularPhone = 0
    CordlessPhone = 0
    SmartPhone = 0
    WiredModemOrVoiceGatewayPhone = 0
    CommonIsdnAccessPhone = 0

    # Enum QBluetoothDeviceInfo.MinorComputerClass
    UncategorizedComputer = 0
    DesktopComputer = 0
    ServerComputer = 0
    LaptopComputer = 0
    HandheldClamShellComputer = 0
    HandheldComputer = 0
    WearableComputer = 0

    # Enum QBluetoothDeviceInfo.MinorMiscellaneousClass
    UncategorizedMiscellaneous = 0

    # Enum QBluetoothDeviceInfo.MajorDeviceClass
    MiscellaneousDevice = 0
    ComputerDevice = 0
    PhoneDevice = 0
    LANAccessDevice = 0
    AudioVideoDevice = 0
    PeripheralDevice = 0
    ImagingDevice = 0
    WearableDevice = 0
    ToyDevice = 0
    HealthDevice = 0
    UncategorizedDevice = 0

    def __init__(self):
        '''void QBluetoothDeviceInfo.__init__()'''
    def __init__(self, address, name, classOfDevice):
        '''void QBluetoothDeviceInfo.__init__(QBluetoothAddress address, str name, int classOfDevice)'''
    def __init__(self, uuid, name, classOfDevice):
        '''void QBluetoothDeviceInfo.__init__(QBluetoothUuid uuid, str name, int classOfDevice)'''
    def __init__(self, other):
        '''void QBluetoothDeviceInfo.__init__(QBluetoothDeviceInfo other)'''
    def deviceUuid(self):
        '''QBluetoothUuid QBluetoothDeviceInfo.deviceUuid()'''
        return QBluetoothUuid()
    def setDeviceUuid(self, uuid):
        '''void QBluetoothDeviceInfo.setDeviceUuid(QBluetoothUuid uuid)'''
    def coreConfigurations(self):
        '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.coreConfigurations()'''
        return QBluetoothDeviceInfo.CoreConfigurations()
    def setCoreConfigurations(self, coreConfigs):
        '''void QBluetoothDeviceInfo.setCoreConfigurations(QBluetoothDeviceInfo.CoreConfigurations coreConfigs)'''
    def serviceUuidsCompleteness(self):
        '''QBluetoothDeviceInfo.DataCompleteness QBluetoothDeviceInfo.serviceUuidsCompleteness()'''
        return QBluetoothDeviceInfo.DataCompleteness()
    def serviceUuids(self, completeness):
        '''list-of-QBluetoothUuid QBluetoothDeviceInfo.serviceUuids(QBluetoothDeviceInfo.DataCompleteness completeness)'''
        return [QBluetoothUuid()]
    def setServiceUuids(self, uuids, completeness):
        '''void QBluetoothDeviceInfo.setServiceUuids(list-of-QBluetoothUuid uuids, QBluetoothDeviceInfo.DataCompleteness completeness)'''
    def setRssi(self, signal):
        '''void QBluetoothDeviceInfo.setRssi(int signal)'''
    def rssi(self):
        '''int QBluetoothDeviceInfo.rssi()'''
        return int()
    def minorDeviceClass(self):
        '''int QBluetoothDeviceInfo.minorDeviceClass()'''
        return int()
    def majorDeviceClass(self):
        '''QBluetoothDeviceInfo.MajorDeviceClass QBluetoothDeviceInfo.majorDeviceClass()'''
        return QBluetoothDeviceInfo.MajorDeviceClass()
    def serviceClasses(self):
        '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.serviceClasses()'''
        return QBluetoothDeviceInfo.ServiceClasses()
    def name(self):
        '''str QBluetoothDeviceInfo.name()'''
        return str()
    def address(self):
        '''QBluetoothAddress QBluetoothDeviceInfo.address()'''
        return QBluetoothAddress()
    def __ne__(self, other):
        '''bool QBluetoothDeviceInfo.__ne__(QBluetoothDeviceInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QBluetoothDeviceInfo.__eq__(QBluetoothDeviceInfo other)'''
        return bool()
    def setCached(self, cached):
        '''void QBluetoothDeviceInfo.setCached(bool cached)'''
    def isCached(self):
        '''bool QBluetoothDeviceInfo.isCached()'''
        return bool()
    def isValid(self):
        '''bool QBluetoothDeviceInfo.isValid()'''
        return bool()
    class CoreConfigurations():
        """"""
        def __init__(self):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__init__()'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __init__(self):
            '''int QBluetoothDeviceInfo.CoreConfigurations.__init__()'''
            return int()
        def __init__(self):
            '''void QBluetoothDeviceInfo.CoreConfigurations.__init__()'''
        def __bool__(self):
            '''int QBluetoothDeviceInfo.CoreConfigurations.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QBluetoothDeviceInfo.CoreConfigurations.__ne__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return bool()
        def __eq__(self, f):
            '''bool QBluetoothDeviceInfo.CoreConfigurations.__eq__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return bool()
        def __invert__(self):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__invert__()'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __and__(self, mask):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__and__(int mask)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __xor__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__xor__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __xor__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__xor__(int f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __or__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__or__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __or__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__or__(int f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __int__(self):
            '''int QBluetoothDeviceInfo.CoreConfigurations.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__ixor__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __ior__(self, f):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__ior__(QBluetoothDeviceInfo.CoreConfigurations f)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
        def __iand__(self, mask):
            '''QBluetoothDeviceInfo.CoreConfigurations QBluetoothDeviceInfo.CoreConfigurations.__iand__(int mask)'''
            return QBluetoothDeviceInfo.CoreConfigurations()
    class ServiceClasses():
        """"""
        def __init__(self):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__init__()'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __init__(self):
            '''int QBluetoothDeviceInfo.ServiceClasses.__init__()'''
            return int()
        def __init__(self):
            '''void QBluetoothDeviceInfo.ServiceClasses.__init__()'''
        def __bool__(self):
            '''int QBluetoothDeviceInfo.ServiceClasses.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QBluetoothDeviceInfo.ServiceClasses.__ne__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return bool()
        def __eq__(self, f):
            '''bool QBluetoothDeviceInfo.ServiceClasses.__eq__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return bool()
        def __invert__(self):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__invert__()'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __and__(self, mask):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__and__(int mask)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __xor__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__xor__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __xor__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__xor__(int f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __or__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__or__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __or__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__or__(int f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __int__(self):
            '''int QBluetoothDeviceInfo.ServiceClasses.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__ixor__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __ior__(self, f):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__ior__(QBluetoothDeviceInfo.ServiceClasses f)'''
            return QBluetoothDeviceInfo.ServiceClasses()
        def __iand__(self, mask):
            '''QBluetoothDeviceInfo.ServiceClasses QBluetoothDeviceInfo.ServiceClasses.__iand__(int mask)'''
            return QBluetoothDeviceInfo.ServiceClasses()


class QBluetoothHostInfo():
    """"""
    def __init__(self):
        '''void QBluetoothHostInfo.__init__()'''
    def __init__(self, other):
        '''void QBluetoothHostInfo.__init__(QBluetoothHostInfo other)'''
    def __ne__(self, other):
        '''bool QBluetoothHostInfo.__ne__(QBluetoothHostInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QBluetoothHostInfo.__eq__(QBluetoothHostInfo other)'''
        return bool()
    def setName(self, name):
        '''void QBluetoothHostInfo.setName(str name)'''
    def name(self):
        '''str QBluetoothHostInfo.name()'''
        return str()
    def setAddress(self, address):
        '''void QBluetoothHostInfo.setAddress(QBluetoothAddress address)'''
    def address(self):
        '''QBluetoothAddress QBluetoothHostInfo.address()'''
        return QBluetoothAddress()


class QBluetoothLocalDevice(QObject):
    """"""
    # Enum QBluetoothLocalDevice.Error
    NoError = 0
    PairingError = 0
    UnknownError = 0

    # Enum QBluetoothLocalDevice.HostMode
    HostPoweredOff = 0
    HostConnectable = 0
    HostDiscoverable = 0
    HostDiscoverableLimitedInquiry = 0

    # Enum QBluetoothLocalDevice.Pairing
    Unpaired = 0
    Paired = 0
    AuthorizedPaired = 0

    def __init__(self, parent = None):
        '''void QBluetoothLocalDevice.__init__(QObject parent = None)'''
    def __init__(self, address, parent = None):
        '''void QBluetoothLocalDevice.__init__(QBluetoothAddress address, QObject parent = None)'''
    deviceDisconnected = pyqtSignal() # void deviceDisconnected(const QBluetoothAddressamp;) - signal
    deviceConnected = pyqtSignal() # void deviceConnected(const QBluetoothAddressamp;) - signal
    error = pyqtSignal() # void error(QBluetoothLocalDevice::Error) - signal
    pairingDisplayConfirmation = pyqtSignal() # void pairingDisplayConfirmation(const QBluetoothAddressamp;,QString) - signal
    pairingDisplayPinCode = pyqtSignal() # void pairingDisplayPinCode(const QBluetoothAddressamp;,QString) - signal
    pairingFinished = pyqtSignal() # void pairingFinished(const QBluetoothAddressamp;,QBluetoothLocalDevice::Pairing) - signal
    hostModeStateChanged = pyqtSignal() # void hostModeStateChanged(QBluetoothLocalDevice::HostMode) - signal
    def pairingConfirmation(self, confirmation):
        '''void QBluetoothLocalDevice.pairingConfirmation(bool confirmation)'''
    def connectedDevices(self):
        '''list-of-QBluetoothAddress QBluetoothLocalDevice.connectedDevices()'''
        return [QBluetoothAddress()]
    def allDevices(self):
        '''static list-of-QBluetoothHostInfo QBluetoothLocalDevice.allDevices()'''
        return [QBluetoothHostInfo()]
    def address(self):
        '''QBluetoothAddress QBluetoothLocalDevice.address()'''
        return QBluetoothAddress()
    def name(self):
        '''str QBluetoothLocalDevice.name()'''
        return str()
    def powerOn(self):
        '''void QBluetoothLocalDevice.powerOn()'''
    def hostMode(self):
        '''QBluetoothLocalDevice.HostMode QBluetoothLocalDevice.hostMode()'''
        return QBluetoothLocalDevice.HostMode()
    def setHostMode(self, mode):
        '''void QBluetoothLocalDevice.setHostMode(QBluetoothLocalDevice.HostMode mode)'''
    def pairingStatus(self, address):
        '''QBluetoothLocalDevice.Pairing QBluetoothLocalDevice.pairingStatus(QBluetoothAddress address)'''
        return QBluetoothLocalDevice.Pairing()
    def requestPairing(self, address, pairing):
        '''void QBluetoothLocalDevice.requestPairing(QBluetoothAddress address, QBluetoothLocalDevice.Pairing pairing)'''
    def isValid(self):
        '''bool QBluetoothLocalDevice.isValid()'''
        return bool()


class QBluetoothServer(QObject):
    """"""
    # Enum QBluetoothServer.Error
    NoError = 0
    UnknownError = 0
    PoweredOffError = 0
    InputOutputError = 0
    ServiceAlreadyRegisteredError = 0
    UnsupportedProtocolError = 0

    def __init__(self, serverType, parent = None):
        '''void QBluetoothServer.__init__(QBluetoothServiceInfo.Protocol serverType, QObject parent = None)'''
    newConnection = pyqtSignal() # void newConnection() - signal
    def error(self):
        '''QBluetoothServer.Error QBluetoothServer.error()'''
        return QBluetoothServer.Error()
    error = pyqtSignal() # void error(QBluetoothServer::Error) - signal
    def serverType(self):
        '''QBluetoothServiceInfo.Protocol QBluetoothServer.serverType()'''
        return QBluetoothServiceInfo.Protocol()
    def securityFlags(self):
        '''QBluetooth.SecurityFlags QBluetoothServer.securityFlags()'''
        return QBluetooth.SecurityFlags()
    def setSecurityFlags(self, security):
        '''void QBluetoothServer.setSecurityFlags(QBluetooth.SecurityFlags security)'''
    def serverPort(self):
        '''int QBluetoothServer.serverPort()'''
        return int()
    def serverAddress(self):
        '''QBluetoothAddress QBluetoothServer.serverAddress()'''
        return QBluetoothAddress()
    def nextPendingConnection(self):
        '''QBluetoothSocket QBluetoothServer.nextPendingConnection()'''
        return QBluetoothSocket()
    def hasPendingConnections(self):
        '''bool QBluetoothServer.hasPendingConnections()'''
        return bool()
    def maxPendingConnections(self):
        '''int QBluetoothServer.maxPendingConnections()'''
        return int()
    def setMaxPendingConnections(self, numConnections):
        '''void QBluetoothServer.setMaxPendingConnections(int numConnections)'''
    def isListening(self):
        '''bool QBluetoothServer.isListening()'''
        return bool()
    def listen(self, address = QBluetoothAddress(), port = 0):
        '''bool QBluetoothServer.listen(QBluetoothAddress address = QBluetoothAddress(), int port = 0)'''
        return bool()
    def listen(self, uuid, serviceName = None):
        '''QBluetoothServiceInfo QBluetoothServer.listen(QBluetoothUuid uuid, str serviceName = '')'''
        return QBluetoothServiceInfo()
    def close(self):
        '''void QBluetoothServer.close()'''


class QBluetoothServiceDiscoveryAgent(QObject):
    """"""
    # Enum QBluetoothServiceDiscoveryAgent.DiscoveryMode
    MinimalDiscovery = 0
    FullDiscovery = 0

    # Enum QBluetoothServiceDiscoveryAgent.Error
    NoError = 0
    InputOutputError = 0
    PoweredOffError = 0
    InvalidBluetoothAdapterError = 0
    UnknownError = 0

    def __init__(self, parent = None):
        '''void QBluetoothServiceDiscoveryAgent.__init__(QObject parent = None)'''
    def __init__(self, deviceAdapter, parent = None):
        '''void QBluetoothServiceDiscoveryAgent.__init__(QBluetoothAddress deviceAdapter, QObject parent = None)'''
    canceled = pyqtSignal() # void canceled() - signal
    finished = pyqtSignal() # void finished() - signal
    serviceDiscovered = pyqtSignal() # void serviceDiscovered(const QBluetoothServiceInfoamp;) - signal
    def clear(self):
        '''void QBluetoothServiceDiscoveryAgent.clear()'''
    def stop(self):
        '''void QBluetoothServiceDiscoveryAgent.stop()'''
    def start(self, mode = None):
        '''void QBluetoothServiceDiscoveryAgent.start(QBluetoothServiceDiscoveryAgent.DiscoveryMode mode = QBluetoothServiceDiscoveryAgent.MinimalDiscovery)'''
    def remoteAddress(self):
        '''QBluetoothAddress QBluetoothServiceDiscoveryAgent.remoteAddress()'''
        return QBluetoothAddress()
    def setRemoteAddress(self, address):
        '''bool QBluetoothServiceDiscoveryAgent.setRemoteAddress(QBluetoothAddress address)'''
        return bool()
    def uuidFilter(self):
        '''list-of-QBluetoothUuid QBluetoothServiceDiscoveryAgent.uuidFilter()'''
        return [QBluetoothUuid()]
    def setUuidFilter(self, uuids):
        '''void QBluetoothServiceDiscoveryAgent.setUuidFilter(list-of-QBluetoothUuid uuids)'''
    def setUuidFilter(self, uuid):
        '''void QBluetoothServiceDiscoveryAgent.setUuidFilter(QBluetoothUuid uuid)'''
    def discoveredServices(self):
        '''list-of-QBluetoothServiceInfo QBluetoothServiceDiscoveryAgent.discoveredServices()'''
        return [QBluetoothServiceInfo()]
    def errorString(self):
        '''str QBluetoothServiceDiscoveryAgent.errorString()'''
        return str()
    def error(self):
        '''QBluetoothServiceDiscoveryAgent.Error QBluetoothServiceDiscoveryAgent.error()'''
        return QBluetoothServiceDiscoveryAgent.Error()
    error = pyqtSignal() # void error(QBluetoothServiceDiscoveryAgent::Error) - signal
    def isActive(self):
        '''bool QBluetoothServiceDiscoveryAgent.isActive()'''
        return bool()


class QBluetoothServiceInfo():
    """"""
    # Enum QBluetoothServiceInfo.Protocol
    UnknownProtocol = 0
    L2capProtocol = 0
    RfcommProtocol = 0

    # Enum QBluetoothServiceInfo.AttributeId
    ServiceRecordHandle = 0
    ServiceClassIds = 0
    ServiceRecordState = 0
    ServiceId = 0
    ProtocolDescriptorList = 0
    BrowseGroupList = 0
    LanguageBaseAttributeIdList = 0
    ServiceInfoTimeToLive = 0
    ServiceAvailability = 0
    BluetoothProfileDescriptorList = 0
    DocumentationUrl = 0
    ClientExecutableUrl = 0
    IconUrl = 0
    AdditionalProtocolDescriptorList = 0
    PrimaryLanguageBase = 0
    ServiceName = 0
    ServiceDescription = 0
    ServiceProvider = 0

    def __init__(self):
        '''void QBluetoothServiceInfo.__init__()'''
    def __init__(self, other):
        '''void QBluetoothServiceInfo.__init__(QBluetoothServiceInfo other)'''
    def serviceClassUuids(self):
        '''list-of-QBluetoothUuid QBluetoothServiceInfo.serviceClassUuids()'''
        return [QBluetoothUuid()]
    def serviceUuid(self):
        '''QBluetoothUuid QBluetoothServiceInfo.serviceUuid()'''
        return QBluetoothUuid()
    def setServiceUuid(self, uuid):
        '''void QBluetoothServiceInfo.setServiceUuid(QBluetoothUuid uuid)'''
    def serviceAvailability(self):
        '''int QBluetoothServiceInfo.serviceAvailability()'''
        return int()
    def setServiceAvailability(self, availability):
        '''void QBluetoothServiceInfo.setServiceAvailability(int availability)'''
    def serviceProvider(self):
        '''str QBluetoothServiceInfo.serviceProvider()'''
        return str()
    def setServiceProvider(self, provider):
        '''void QBluetoothServiceInfo.setServiceProvider(str provider)'''
    def serviceDescription(self):
        '''str QBluetoothServiceInfo.serviceDescription()'''
        return str()
    def setServiceDescription(self, description):
        '''void QBluetoothServiceInfo.setServiceDescription(str description)'''
    def serviceName(self):
        '''str QBluetoothServiceInfo.serviceName()'''
        return str()
    def setServiceName(self, name):
        '''void QBluetoothServiceInfo.setServiceName(str name)'''
    def setAttribute(self, attributeId, value):
        '''void QBluetoothServiceInfo.setAttribute(int attributeId, QBluetoothUuid value)'''
    def setAttribute(self, attributeId, value):
        '''void QBluetoothServiceInfo.setAttribute(int attributeId, list-of-object value)'''
    def setAttribute(self, attributeId, value):
        '''void QBluetoothServiceInfo.setAttribute(int attributeId, QVariant value)'''
    def unregisterService(self):
        '''bool QBluetoothServiceInfo.unregisterService()'''
        return bool()
    def registerService(self, localAdapter = QBluetoothAddress()):
        '''bool QBluetoothServiceInfo.registerService(QBluetoothAddress localAdapter = QBluetoothAddress())'''
        return bool()
    def isRegistered(self):
        '''bool QBluetoothServiceInfo.isRegistered()'''
        return bool()
    def protocolDescriptor(self, protocol):
        '''list-of-object QBluetoothServiceInfo.protocolDescriptor(QBluetoothUuid.ProtocolUuid protocol)'''
        return [object()]
    def serverChannel(self):
        '''int QBluetoothServiceInfo.serverChannel()'''
        return int()
    def protocolServiceMultiplexer(self):
        '''int QBluetoothServiceInfo.protocolServiceMultiplexer()'''
        return int()
    def socketProtocol(self):
        '''QBluetoothServiceInfo.Protocol QBluetoothServiceInfo.socketProtocol()'''
        return QBluetoothServiceInfo.Protocol()
    def removeAttribute(self, attributeId):
        '''void QBluetoothServiceInfo.removeAttribute(int attributeId)'''
    def contains(self, attributeId):
        '''bool QBluetoothServiceInfo.contains(int attributeId)'''
        return bool()
    def attributes(self):
        '''list-of-int QBluetoothServiceInfo.attributes()'''
        return [int()]
    def attribute(self, attributeId):
        '''QVariant QBluetoothServiceInfo.attribute(int attributeId)'''
        return QVariant()
    def device(self):
        '''QBluetoothDeviceInfo QBluetoothServiceInfo.device()'''
        return QBluetoothDeviceInfo()
    def setDevice(self, info):
        '''void QBluetoothServiceInfo.setDevice(QBluetoothDeviceInfo info)'''
    def isComplete(self):
        '''bool QBluetoothServiceInfo.isComplete()'''
        return bool()
    def isValid(self):
        '''bool QBluetoothServiceInfo.isValid()'''
        return bool()


class QBluetoothSocket(QIODevice):
    """"""
    # Enum QBluetoothSocket.SocketError
    NoSocketError = 0
    UnknownSocketError = 0
    HostNotFoundError = 0
    ServiceNotFoundError = 0
    NetworkError = 0
    UnsupportedProtocolError = 0
    OperationError = 0

    # Enum QBluetoothSocket.SocketState
    UnconnectedState = 0
    ServiceLookupState = 0
    ConnectingState = 0
    ConnectedState = 0
    BoundState = 0
    ClosingState = 0
    ListeningState = 0

    def __init__(self, socketType, parent = None):
        '''void QBluetoothSocket.__init__(QBluetoothServiceInfo.Protocol socketType, QObject parent = None)'''
    def __init__(self, parent = None):
        '''void QBluetoothSocket.__init__(QObject parent = None)'''
    def doDeviceDiscovery(self, service, openMode):
        '''void QBluetoothSocket.doDeviceDiscovery(QBluetoothServiceInfo service, QIODevice.OpenMode openMode)'''
    def setSocketError(self, error):
        '''void QBluetoothSocket.setSocketError(QBluetoothSocket.SocketError error)'''
    def setSocketState(self, state):
        '''void QBluetoothSocket.setSocketState(QBluetoothSocket.SocketState state)'''
    def writeData(self, data):
        '''int QBluetoothSocket.writeData(str data)'''
        return int()
    def readData(self, maxlen):
        '''str QBluetoothSocket.readData(int maxlen)'''
        return str()
    stateChanged = pyqtSignal() # void stateChanged(QBluetoothSocket::SocketState) - signal
    disconnected = pyqtSignal() # void disconnected() - signal
    connected = pyqtSignal() # void connected() - signal
    def errorString(self):
        '''str QBluetoothSocket.errorString()'''
        return str()
    def error(self):
        '''QBluetoothSocket.SocketError QBluetoothSocket.error()'''
        return QBluetoothSocket.SocketError()
    error = pyqtSignal() # void error(QBluetoothSocket::SocketError) - signal
    def state(self):
        '''QBluetoothSocket.SocketState QBluetoothSocket.state()'''
        return QBluetoothSocket.SocketState()
    def socketType(self):
        '''QBluetoothServiceInfo.Protocol QBluetoothSocket.socketType()'''
        return QBluetoothServiceInfo.Protocol()
    def socketDescriptor(self):
        '''int QBluetoothSocket.socketDescriptor()'''
        return int()
    def setSocketDescriptor(self, socketDescriptor, socketType, state = None, mode = None):
        '''bool QBluetoothSocket.setSocketDescriptor(int socketDescriptor, QBluetoothServiceInfo.Protocol socketType, QBluetoothSocket.SocketState state = QBluetoothSocket.ConnectedState, QIODevice.OpenMode mode = QIODevice.ReadWrite)'''
        return bool()
    def peerPort(self):
        '''int QBluetoothSocket.peerPort()'''
        return int()
    def peerAddress(self):
        '''QBluetoothAddress QBluetoothSocket.peerAddress()'''
        return QBluetoothAddress()
    def peerName(self):
        '''str QBluetoothSocket.peerName()'''
        return str()
    def localPort(self):
        '''int QBluetoothSocket.localPort()'''
        return int()
    def localAddress(self):
        '''QBluetoothAddress QBluetoothSocket.localAddress()'''
        return QBluetoothAddress()
    def localName(self):
        '''str QBluetoothSocket.localName()'''
        return str()
    def disconnectFromService(self):
        '''void QBluetoothSocket.disconnectFromService()'''
    def connectToService(self, service, mode = None):
        '''void QBluetoothSocket.connectToService(QBluetoothServiceInfo service, QIODevice.OpenMode mode = QIODevice.ReadWrite)'''
    def connectToService(self, address, uuid, mode = None):
        '''void QBluetoothSocket.connectToService(QBluetoothAddress address, QBluetoothUuid uuid, QIODevice.OpenMode mode = QIODevice.ReadWrite)'''
    def connectToService(self, address, port, mode = None):
        '''void QBluetoothSocket.connectToService(QBluetoothAddress address, int port, QIODevice.OpenMode mode = QIODevice.ReadWrite)'''
    def canReadLine(self):
        '''bool QBluetoothSocket.canReadLine()'''
        return bool()
    def bytesToWrite(self):
        '''int QBluetoothSocket.bytesToWrite()'''
        return int()
    def bytesAvailable(self):
        '''int QBluetoothSocket.bytesAvailable()'''
        return int()
    def isSequential(self):
        '''bool QBluetoothSocket.isSequential()'''
        return bool()
    def close(self):
        '''void QBluetoothSocket.close()'''
    def abort(self):
        '''void QBluetoothSocket.abort()'''


class QBluetoothTransferManager(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QBluetoothTransferManager.__init__(QObject parent = None)'''
    finished = pyqtSignal() # void finished(QBluetoothTransferReply*) - signal
    def put(self, request, data):
        '''QBluetoothTransferReply QBluetoothTransferManager.put(QBluetoothTransferRequest request, QIODevice data)'''
        return QBluetoothTransferReply()


class QBluetoothTransferReply(QObject):
    """"""
    # Enum QBluetoothTransferReply.TransferError
    NoError = 0
    UnknownError = 0
    FileNotFoundError = 0
    HostNotFoundError = 0
    UserCanceledTransferError = 0
    IODeviceNotReadableError = 0
    ResourceBusyError = 0
    SessionError = 0

    def __init__(self, parent = None):
        '''void QBluetoothTransferReply.__init__(QObject parent = None)'''
    def setRequest(self, request):
        '''void QBluetoothTransferReply.setRequest(QBluetoothTransferRequest request)'''
    def setManager(self, manager):
        '''void QBluetoothTransferReply.setManager(QBluetoothTransferManager manager)'''
    transferProgress = pyqtSignal() # void transferProgress(qint64,qint64) - signal
    finished = pyqtSignal() # void finished(QBluetoothTransferReply*) - signal
    def abort(self):
        '''void QBluetoothTransferReply.abort()'''
    def request(self):
        '''QBluetoothTransferRequest QBluetoothTransferReply.request()'''
        return QBluetoothTransferRequest()
    def errorString(self):
        '''abstract str QBluetoothTransferReply.errorString()'''
        return str()
    def error(self):
        '''abstract QBluetoothTransferReply.TransferError QBluetoothTransferReply.error()'''
        return QBluetoothTransferReply.TransferError()
    error = pyqtSignal() # void error(QBluetoothTransferReply::TransferError) - signal
    def manager(self):
        '''QBluetoothTransferManager QBluetoothTransferReply.manager()'''
        return QBluetoothTransferManager()
    def isRunning(self):
        '''abstract bool QBluetoothTransferReply.isRunning()'''
        return bool()
    def isFinished(self):
        '''abstract bool QBluetoothTransferReply.isFinished()'''
        return bool()


class QBluetoothTransferRequest():
    """"""
    # Enum QBluetoothTransferRequest.Attribute
    DescriptionAttribute = 0
    TimeAttribute = 0
    TypeAttribute = 0
    LengthAttribute = 0
    NameAttribute = 0

    def __init__(self, address = QBluetoothAddress()):
        '''void QBluetoothTransferRequest.__init__(QBluetoothAddress address = QBluetoothAddress())'''
    def __init__(self, other):
        '''void QBluetoothTransferRequest.__init__(QBluetoothTransferRequest other)'''
    def __eq__(self, other):
        '''bool QBluetoothTransferRequest.__eq__(QBluetoothTransferRequest other)'''
        return bool()
    def __ne__(self, other):
        '''bool QBluetoothTransferRequest.__ne__(QBluetoothTransferRequest other)'''
        return bool()
    def address(self):
        '''QBluetoothAddress QBluetoothTransferRequest.address()'''
        return QBluetoothAddress()
    def setAttribute(self, code, value):
        '''void QBluetoothTransferRequest.setAttribute(QBluetoothTransferRequest.Attribute code, QVariant value)'''
    def attribute(self, code, defaultValue = QVariant()):
        '''QVariant QBluetoothTransferRequest.attribute(QBluetoothTransferRequest.Attribute code, QVariant defaultValue = QVariant())'''
        return QVariant()


class QBluetoothUuid(QUuid):
    """"""
    # Enum QBluetoothUuid.DescriptorType
    UnknownDescriptorType = 0
    CharacteristicExtendedProperties = 0
    CharacteristicUserDescription = 0
    ClientCharacteristicConfiguration = 0
    ServerCharacteristicConfiguration = 0
    CharacteristicPresentationFormat = 0
    CharacteristicAggregateFormat = 0
    ValidRange = 0
    ExternalReportReference = 0
    ReportReference = 0
    EnvironmentalSensingConfiguration = 0
    EnvironmentalSensingMeasurement = 0
    EnvironmentalSensingTriggerSetting = 0

    # Enum QBluetoothUuid.CharacteristicType
    DeviceName = 0
    Appearance = 0
    PeripheralPrivacyFlag = 0
    ReconnectionAddress = 0
    PeripheralPreferredConnectionParameters = 0
    ServiceChanged = 0
    AlertLevel = 0
    TxPowerLevel = 0
    DateTime = 0
    DayOfWeek = 0
    DayDateTime = 0
    ExactTime256 = 0
    DSTOffset = 0
    TimeZone = 0
    LocalTimeInformation = 0
    TimeWithDST = 0
    TimeAccuracy = 0
    TimeSource = 0
    ReferenceTimeInformation = 0
    TimeUpdateControlPoint = 0
    TimeUpdateState = 0
    GlucoseMeasurement = 0
    BatteryLevel = 0
    TemperatureMeasurement = 0
    TemperatureType = 0
    IntermediateTemperature = 0
    MeasurementInterval = 0
    BootKeyboardInputReport = 0
    SystemID = 0
    ModelNumberString = 0
    SerialNumberString = 0
    FirmwareRevisionString = 0
    HardwareRevisionString = 0
    SoftwareRevisionString = 0
    ManufacturerNameString = 0
    IEEE1107320601RegulatoryCertificationDataList = 0
    CurrentTime = 0
    ScanRefresh = 0
    BootKeyboardOutputReport = 0
    BootMouseInputReport = 0
    GlucoseMeasurementContext = 0
    BloodPressureMeasurement = 0
    IntermediateCuffPressure = 0
    HeartRateMeasurement = 0
    BodySensorLocation = 0
    HeartRateControlPoint = 0
    AlertStatus = 0
    RingerControlPoint = 0
    RingerSetting = 0
    AlertCategoryIDBitMask = 0
    AlertCategoryID = 0
    AlertNotificationControlPoint = 0
    UnreadAlertStatus = 0
    NewAlert = 0
    SupportedNewAlertCategory = 0
    SupportedUnreadAlertCategory = 0
    BloodPressureFeature = 0
    HIDInformation = 0
    ReportMap = 0
    HIDControlPoint = 0
    Report = 0
    ProtocolMode = 0
    ScanIntervalWindow = 0
    PnPID = 0
    GlucoseFeature = 0
    RecordAccessControlPoint = 0
    RSCMeasurement = 0
    RSCFeature = 0
    SCControlPoint = 0
    CSCMeasurement = 0
    CSCFeature = 0
    SensorLocation = 0
    CyclingPowerMeasurement = 0
    CyclingPowerVector = 0
    CyclingPowerFeature = 0
    CyclingPowerControlPoint = 0
    LocationAndSpeed = 0
    Navigation = 0
    PositionQuality = 0
    LNFeature = 0
    LNControlPoint = 0
    MagneticDeclination = 0
    Elevation = 0
    Pressure = 0
    Temperature = 0
    Humidity = 0
    TrueWindSpeed = 0
    TrueWindDirection = 0
    ApparentWindSpeed = 0
    ApparentWindDirection = 0
    GustFactor = 0
    PollenConcentration = 0
    UVIndex = 0
    Irradiance = 0
    Rainfall = 0
    WindChill = 0
    HeatIndex = 0
    DewPoint = 0
    DescriptorValueChanged = 0
    AerobicHeartRateLowerLimit = 0
    AerobicThreshold = 0
    Age = 0
    AnaerobicHeartRateLowerLimit = 0
    AnaerobicHeartRateUpperLimit = 0
    AnaerobicThreshold = 0
    AerobicHeartRateUpperLimit = 0
    DateOfBirth = 0
    DateOfThresholdAssessment = 0
    EmailAddress = 0
    FatBurnHeartRateLowerLimit = 0
    FatBurnHeartRateUpperLimit = 0
    FirstName = 0
    FiveZoneHeartRateLimits = 0
    Gender = 0
    HeartRateMax = 0
    Height = 0
    HipCircumference = 0
    LastName = 0
    MaximumRecommendedHeartRate = 0
    RestingHeartRate = 0
    SportTypeForAerobicAnaerobicThresholds = 0
    ThreeZoneHeartRateLimits = 0
    TwoZoneHeartRateLimits = 0
    VO2Max = 0
    WaistCircumference = 0
    Weight = 0
    DatabaseChangeIncrement = 0
    UserIndex = 0
    BodyCompositionFeature = 0
    BodyCompositionMeasurement = 0
    WeightMeasurement = 0
    WeightScaleFeature = 0
    UserControlPoint = 0
    MagneticFluxDensity2D = 0
    MagneticFluxDensity3D = 0
    Language = 0
    BarometricPressureTrend = 0

    # Enum QBluetoothUuid.ServiceClassUuid
    ServiceDiscoveryServer = 0
    BrowseGroupDescriptor = 0
    PublicBrowseGroup = 0
    SerialPort = 0
    LANAccessUsingPPP = 0
    DialupNetworking = 0
    IrMCSync = 0
    ObexObjectPush = 0
    OBEXFileTransfer = 0
    IrMCSyncCommand = 0
    Headset = 0
    AudioSource = 0
    AudioSink = 0
    AV_RemoteControlTarget = 0
    AdvancedAudioDistribution = 0
    AV_RemoteControl = 0
    AV_RemoteControlController = 0
    HeadsetAG = 0
    PANU = 0
    NAP = 0
    GN = 0
    DirectPrinting = 0
    ReferencePrinting = 0
    ImagingResponder = 0
    ImagingAutomaticArchive = 0
    ImagingReferenceObjects = 0
    Handsfree = 0
    HandsfreeAudioGateway = 0
    DirectPrintingReferenceObjectsService = 0
    ReflectedUI = 0
    BasicPrinting = 0
    PrintingStatus = 0
    HumanInterfaceDeviceService = 0
    HardcopyCableReplacement = 0
    HCRPrint = 0
    HCRScan = 0
    SIMAccess = 0
    PhonebookAccessPCE = 0
    PhonebookAccessPSE = 0
    PhonebookAccess = 0
    HeadsetHS = 0
    MessageAccessServer = 0
    MessageNotificationServer = 0
    MessageAccessProfile = 0
    PnPInformation = 0
    GenericNetworking = 0
    GenericFileTransfer = 0
    GenericAudio = 0
    GenericTelephony = 0
    VideoSource = 0
    VideoSink = 0
    VideoDistribution = 0
    HDP = 0
    HDPSource = 0
    HDPSink = 0
    BasicImage = 0
    GNSS = 0
    GNSSServer = 0
    Display3D = 0
    Glasses3D = 0
    Synchronization3D = 0
    MPSProfile = 0
    MPSService = 0
    GenericAccess = 0
    GenericAttribute = 0
    ImmediateAlert = 0
    LinkLoss = 0
    TxPower = 0
    CurrentTimeService = 0
    ReferenceTimeUpdateService = 0
    NextDSTChangeService = 0
    Glucose = 0
    HealthThermometer = 0
    DeviceInformation = 0
    HeartRate = 0
    PhoneAlertStatusService = 0
    BatteryService = 0
    BloodPressure = 0
    AlertNotificationService = 0
    HumanInterfaceDevice = 0
    ScanParameters = 0
    RunningSpeedAndCadence = 0
    CyclingSpeedAndCadence = 0
    CyclingPower = 0
    LocationAndNavigation = 0
    EnvironmentalSensing = 0
    BodyComposition = 0
    UserData = 0
    WeightScale = 0
    BondManagement = 0
    ContinuousGlucoseMonitoring = 0

    # Enum QBluetoothUuid.ProtocolUuid
    Sdp = 0
    Udp = 0
    Rfcomm = 0
    Tcp = 0
    TcsBin = 0
    TcsAt = 0
    Att = 0
    Obex = 0
    Ip = 0
    Ftp = 0
    Http = 0
    Wsp = 0
    Bnep = 0
    Upnp = 0
    Hidp = 0
    HardcopyControlChannel = 0
    HardcopyDataChannel = 0
    HardcopyNotification = 0
    Avctp = 0
    Avdtp = 0
    Cmtp = 0
    UdiCPlain = 0
    McapControlChannel = 0
    McapDataChannel = 0
    L2cap = 0

    def __init__(self):
        '''void QBluetoothUuid.__init__()'''
    def __init__(self, uuid):
        '''void QBluetoothUuid.__init__(int uuid)'''
    def __init__(self, uuid):
        '''void QBluetoothUuid.__init__(16-tuple-of-int uuid)'''
    def __init__(self, uuid):
        '''void QBluetoothUuid.__init__(str uuid)'''
    def __init__(self, uuid):
        '''void QBluetoothUuid.__init__(QBluetoothUuid uuid)'''
    def __init__(self, uuid):
        '''void QBluetoothUuid.__init__(QUuid uuid)'''
    def __ne__(self, other):
        '''bool QBluetoothUuid.__ne__(QBluetoothUuid other)'''
        return bool()
    def descriptorToString(self, uuid):
        '''static str QBluetoothUuid.descriptorToString(QBluetoothUuid.DescriptorType uuid)'''
        return str()
    def characteristicToString(self, uuid):
        '''static str QBluetoothUuid.characteristicToString(QBluetoothUuid.CharacteristicType uuid)'''
        return str()
    def protocolToString(self, uuid):
        '''static str QBluetoothUuid.protocolToString(QBluetoothUuid.ProtocolUuid uuid)'''
        return str()
    def serviceClassToString(self, uuid):
        '''static str QBluetoothUuid.serviceClassToString(QBluetoothUuid.ServiceClassUuid uuid)'''
        return str()
    def toUInt128(self):
        '''16-tuple-of-int QBluetoothUuid.toUInt128()'''
        return 16-tuple-of-int()
    def toUInt32(self, ok):
        '''int QBluetoothUuid.toUInt32(bool ok)'''
        return int()
    def toUInt16(self, ok):
        '''int QBluetoothUuid.toUInt16(bool ok)'''
        return int()
    def minimumSize(self):
        '''int QBluetoothUuid.minimumSize()'''
        return int()
    def __eq__(self, other):
        '''bool QBluetoothUuid.__eq__(QBluetoothUuid other)'''
        return bool()


class QLowEnergyCharacteristic():
    """"""
    # Enum QLowEnergyCharacteristic.PropertyType
    Unknown = 0
    Broadcasting = 0
    Read = 0
    WriteNoResponse = 0
    Write = 0
    Notify = 0
    Indicate = 0
    WriteSigned = 0
    ExtendedProperty = 0

    def __init__(self):
        '''void QLowEnergyCharacteristic.__init__()'''
    def __init__(self, other):
        '''void QLowEnergyCharacteristic.__init__(QLowEnergyCharacteristic other)'''
    def isValid(self):
        '''bool QLowEnergyCharacteristic.isValid()'''
        return bool()
    def descriptors(self):
        '''list-of-QLowEnergyDescriptor QLowEnergyCharacteristic.descriptors()'''
        return [QLowEnergyDescriptor()]
    def descriptor(self, uuid):
        '''QLowEnergyDescriptor QLowEnergyCharacteristic.descriptor(QBluetoothUuid uuid)'''
        return QLowEnergyDescriptor()
    def handle(self):
        '''int QLowEnergyCharacteristic.handle()'''
        return int()
    def properties(self):
        '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.properties()'''
        return QLowEnergyCharacteristic.PropertyTypes()
    def value(self):
        '''QByteArray QLowEnergyCharacteristic.value()'''
        return QByteArray()
    def uuid(self):
        '''QBluetoothUuid QLowEnergyCharacteristic.uuid()'''
        return QBluetoothUuid()
    def name(self):
        '''str QLowEnergyCharacteristic.name()'''
        return str()
    def __ne__(self, other):
        '''bool QLowEnergyCharacteristic.__ne__(QLowEnergyCharacteristic other)'''
        return bool()
    def __eq__(self, other):
        '''bool QLowEnergyCharacteristic.__eq__(QLowEnergyCharacteristic other)'''
        return bool()
    class PropertyTypes():
        """"""
        def __init__(self):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__init__()'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __init__(self):
            '''int QLowEnergyCharacteristic.PropertyTypes.__init__()'''
            return int()
        def __init__(self):
            '''void QLowEnergyCharacteristic.PropertyTypes.__init__()'''
        def __bool__(self):
            '''int QLowEnergyCharacteristic.PropertyTypes.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QLowEnergyCharacteristic.PropertyTypes.__ne__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return bool()
        def __eq__(self, f):
            '''bool QLowEnergyCharacteristic.PropertyTypes.__eq__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return bool()
        def __invert__(self):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__invert__()'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __and__(self, mask):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__and__(int mask)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __xor__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__xor__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __xor__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__xor__(int f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __or__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__or__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __or__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__or__(int f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __int__(self):
            '''int QLowEnergyCharacteristic.PropertyTypes.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__ixor__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __ior__(self, f):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__ior__(QLowEnergyCharacteristic.PropertyTypes f)'''
            return QLowEnergyCharacteristic.PropertyTypes()
        def __iand__(self, mask):
            '''QLowEnergyCharacteristic.PropertyTypes QLowEnergyCharacteristic.PropertyTypes.__iand__(int mask)'''
            return QLowEnergyCharacteristic.PropertyTypes()


class QLowEnergyController(QObject):
    """"""
    # Enum QLowEnergyController.RemoteAddressType
    PublicAddress = 0
    RandomAddress = 0

    # Enum QLowEnergyController.ControllerState
    UnconnectedState = 0
    ConnectingState = 0
    ConnectedState = 0
    DiscoveringState = 0
    DiscoveredState = 0
    ClosingState = 0

    # Enum QLowEnergyController.Error
    NoError = 0
    UnknownError = 0
    UnknownRemoteDeviceError = 0
    NetworkError = 0
    InvalidBluetoothAdapterError = 0
    ConnectionError = 0

    def __init__(self, remoteDevice, parent = None):
        '''void QLowEnergyController.__init__(QBluetoothDeviceInfo remoteDevice, QObject parent = None)'''
    def __init__(self, remoteDevice, parent = None):
        '''void QLowEnergyController.__init__(QBluetoothAddress remoteDevice, QObject parent = None)'''
    def __init__(self, remoteDevice, localDevice, parent = None):
        '''void QLowEnergyController.__init__(QBluetoothAddress remoteDevice, QBluetoothAddress localDevice, QObject parent = None)'''
    discoveryFinished = pyqtSignal() # void discoveryFinished() - signal
    serviceDiscovered = pyqtSignal() # void serviceDiscovered(const QBluetoothUuidamp;) - signal
    stateChanged = pyqtSignal() # void stateChanged(QLowEnergyController::ControllerState) - signal
    disconnected = pyqtSignal() # void disconnected() - signal
    connected = pyqtSignal() # void connected() - signal
    def remoteName(self):
        '''str QLowEnergyController.remoteName()'''
        return str()
    def errorString(self):
        '''str QLowEnergyController.errorString()'''
        return str()
    def error(self):
        '''QLowEnergyController.Error QLowEnergyController.error()'''
        return QLowEnergyController.Error()
    error = pyqtSignal() # void error(QLowEnergyController::Error) - signal
    def createServiceObject(self, service, parent = None):
        '''QLowEnergyService QLowEnergyController.createServiceObject(QBluetoothUuid service, QObject parent = None)'''
        return QLowEnergyService()
    def services(self):
        '''list-of-QBluetoothUuid QLowEnergyController.services()'''
        return [QBluetoothUuid()]
    def discoverServices(self):
        '''void QLowEnergyController.discoverServices()'''
    def disconnectFromDevice(self):
        '''void QLowEnergyController.disconnectFromDevice()'''
    def connectToDevice(self):
        '''void QLowEnergyController.connectToDevice()'''
    def setRemoteAddressType(self, type):
        '''void QLowEnergyController.setRemoteAddressType(QLowEnergyController.RemoteAddressType type)'''
    def remoteAddressType(self):
        '''QLowEnergyController.RemoteAddressType QLowEnergyController.remoteAddressType()'''
        return QLowEnergyController.RemoteAddressType()
    def state(self):
        '''QLowEnergyController.ControllerState QLowEnergyController.state()'''
        return QLowEnergyController.ControllerState()
    def remoteAddress(self):
        '''QBluetoothAddress QLowEnergyController.remoteAddress()'''
        return QBluetoothAddress()
    def localAddress(self):
        '''QBluetoothAddress QLowEnergyController.localAddress()'''
        return QBluetoothAddress()


class QLowEnergyDescriptor():
    """"""
    def __init__(self):
        '''void QLowEnergyDescriptor.__init__()'''
    def __init__(self, other):
        '''void QLowEnergyDescriptor.__init__(QLowEnergyDescriptor other)'''
    def type(self):
        '''QBluetoothUuid.DescriptorType QLowEnergyDescriptor.type()'''
        return QBluetoothUuid.DescriptorType()
    def name(self):
        '''str QLowEnergyDescriptor.name()'''
        return str()
    def handle(self):
        '''int QLowEnergyDescriptor.handle()'''
        return int()
    def uuid(self):
        '''QBluetoothUuid QLowEnergyDescriptor.uuid()'''
        return QBluetoothUuid()
    def value(self):
        '''QByteArray QLowEnergyDescriptor.value()'''
        return QByteArray()
    def isValid(self):
        '''bool QLowEnergyDescriptor.isValid()'''
        return bool()
    def __ne__(self, other):
        '''bool QLowEnergyDescriptor.__ne__(QLowEnergyDescriptor other)'''
        return bool()
    def __eq__(self, other):
        '''bool QLowEnergyDescriptor.__eq__(QLowEnergyDescriptor other)'''
        return bool()


class QLowEnergyService(QObject):
    """"""
    # Enum QLowEnergyService.WriteMode
    WriteWithResponse = 0
    WriteWithoutResponse = 0

    # Enum QLowEnergyService.ServiceState
    InvalidService = 0
    DiscoveryRequired = 0
    DiscoveringServices = 0
    ServiceDiscovered = 0

    # Enum QLowEnergyService.ServiceError
    NoError = 0
    OperationError = 0
    CharacteristicWriteError = 0
    DescriptorWriteError = 0
    CharacteristicReadError = 0
    DescriptorReadError = 0
    UnknownError = 0

    # Enum QLowEnergyService.ServiceType
    PrimaryService = 0
    IncludedService = 0

    descriptorRead = pyqtSignal() # void descriptorRead(const QLowEnergyDescriptoramp;,const QByteArrayamp;) - signal
    characteristicRead = pyqtSignal() # void characteristicRead(const QLowEnergyCharacteristicamp;,const QByteArrayamp;) - signal
    def readDescriptor(self, descriptor):
        '''void QLowEnergyService.readDescriptor(QLowEnergyDescriptor descriptor)'''
    def readCharacteristic(self, characteristic):
        '''void QLowEnergyService.readCharacteristic(QLowEnergyCharacteristic characteristic)'''
    descriptorWritten = pyqtSignal() # void descriptorWritten(const QLowEnergyDescriptoramp;,const QByteArrayamp;) - signal
    characteristicWritten = pyqtSignal() # void characteristicWritten(const QLowEnergyCharacteristicamp;,const QByteArrayamp;) - signal
    characteristicChanged = pyqtSignal() # void characteristicChanged(const QLowEnergyCharacteristicamp;,const QByteArrayamp;) - signal
    stateChanged = pyqtSignal() # void stateChanged(QLowEnergyService::ServiceState) - signal
    def writeDescriptor(self, descriptor, newValue):
        '''void QLowEnergyService.writeDescriptor(QLowEnergyDescriptor descriptor, QByteArray newValue)'''
    def writeCharacteristic(self, characteristic, newValue, mode = None):
        '''void QLowEnergyService.writeCharacteristic(QLowEnergyCharacteristic characteristic, QByteArray newValue, QLowEnergyService.WriteMode mode = QLowEnergyService.WriteWithResponse)'''
    def contains(self, characteristic):
        '''bool QLowEnergyService.contains(QLowEnergyCharacteristic characteristic)'''
        return bool()
    def contains(self, descriptor):
        '''bool QLowEnergyService.contains(QLowEnergyDescriptor descriptor)'''
        return bool()
    def error(self):
        '''QLowEnergyService.ServiceError QLowEnergyService.error()'''
        return QLowEnergyService.ServiceError()
    error = pyqtSignal() # void error(QLowEnergyService::ServiceError) - signal
    def discoverDetails(self):
        '''void QLowEnergyService.discoverDetails()'''
    def serviceName(self):
        '''str QLowEnergyService.serviceName()'''
        return str()
    def serviceUuid(self):
        '''QBluetoothUuid QLowEnergyService.serviceUuid()'''
        return QBluetoothUuid()
    def characteristics(self):
        '''list-of-QLowEnergyCharacteristic QLowEnergyService.characteristics()'''
        return [QLowEnergyCharacteristic()]
    def characteristic(self, uuid):
        '''QLowEnergyCharacteristic QLowEnergyService.characteristic(QBluetoothUuid uuid)'''
        return QLowEnergyCharacteristic()
    def state(self):
        '''QLowEnergyService.ServiceState QLowEnergyService.state()'''
        return QLowEnergyService.ServiceState()
    def type(self):
        '''QLowEnergyService.ServiceTypes QLowEnergyService.type()'''
        return QLowEnergyService.ServiceTypes()
    def includedServices(self):
        '''list-of-QBluetoothUuid QLowEnergyService.includedServices()'''
        return [QBluetoothUuid()]
    class ServiceTypes():
        """"""
        def __init__(self):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__init__()'''
            return QLowEnergyService.ServiceTypes()
        def __init__(self):
            '''int QLowEnergyService.ServiceTypes.__init__()'''
            return int()
        def __init__(self):
            '''void QLowEnergyService.ServiceTypes.__init__()'''
        def __bool__(self):
            '''int QLowEnergyService.ServiceTypes.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QLowEnergyService.ServiceTypes.__ne__(QLowEnergyService.ServiceTypes f)'''
            return bool()
        def __eq__(self, f):
            '''bool QLowEnergyService.ServiceTypes.__eq__(QLowEnergyService.ServiceTypes f)'''
            return bool()
        def __invert__(self):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__invert__()'''
            return QLowEnergyService.ServiceTypes()
        def __and__(self, mask):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__and__(int mask)'''
            return QLowEnergyService.ServiceTypes()
        def __xor__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__xor__(QLowEnergyService.ServiceTypes f)'''
            return QLowEnergyService.ServiceTypes()
        def __xor__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__xor__(int f)'''
            return QLowEnergyService.ServiceTypes()
        def __or__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__or__(QLowEnergyService.ServiceTypes f)'''
            return QLowEnergyService.ServiceTypes()
        def __or__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__or__(int f)'''
            return QLowEnergyService.ServiceTypes()
        def __int__(self):
            '''int QLowEnergyService.ServiceTypes.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__ixor__(QLowEnergyService.ServiceTypes f)'''
            return QLowEnergyService.ServiceTypes()
        def __ior__(self, f):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__ior__(QLowEnergyService.ServiceTypes f)'''
            return QLowEnergyService.ServiceTypes()
        def __iand__(self, mask):
            '''QLowEnergyService.ServiceTypes QLowEnergyService.ServiceTypes.__iand__(int mask)'''
            return QLowEnergyService.ServiceTypes()


